=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2011-01-10 22:20:12 +0000
+++ bzrlib/branch.py	2011-01-12 01:01:53 +0000
@@ -1380,13 +1380,8 @@
         """Return the most suitable metadir for a checkout of this branch.
         Weaves are used if this branch's repository uses weaves.
         """
-        if isinstance(self.bzrdir, bzrdir.BzrDirPreSplitOut):
-            from bzrlib.repofmt import weaverepo
-            format = bzrdir.BzrDirMetaFormat1()
-            format.repository_format = weaverepo.RepositoryFormat7()
-        else:
-            format = self.repository.bzrdir.checkout_metadir()
-            format.set_branch_format(self._format)
+        format = self.repository.bzrdir.checkout_metadir()
+        format.set_branch_format(self._format)
         return format
 
     def create_clone_on_transport(self, to_transport, revision_id=None,
@@ -2057,7 +2052,7 @@
             raise NotImplementedError
         if found_repository is None:
             found_repository = a_bzrdir.open_repository()
-        return BzrBranch(_format=self,
+        return BzrBranchPreSplitOut(_format=self,
                          _control_files=a_bzrdir._control_files,
                          a_bzrdir=a_bzrdir,
                          name=name,
@@ -2698,6 +2693,19 @@
                 mode=self.bzrdir._get_file_mode())
 
 
+class BzrBranchPreSplitOut(BzrBranch):
+
+    def _get_checkout_format(self):
+        """Return the most suitable metadir for a checkout of this branch.
+        Weaves are used if this branch's repository uses weaves.
+        """
+        from bzrlib.repofmt.weaverepo import RepositoryFormat7
+        from bzrlib.bzrdir import BzrDirMetaFormat1
+        format = BzrDirMetaFormat1()
+        format.repository_format = RepositoryFormat7()
+        return format
+
+
 class BzrBranch5(BzrBranch):
     """A format 5 branch. This supports new features over plain branches.
 
@@ -3453,7 +3461,8 @@
         if local and not bound_location:
             raise errors.LocalRequiresBoundBranch()
         master_branch = None
-        if not local and bound_location and self.source.user_url != bound_location:
+        source_is_master = (self.source.user_url == bound_location)
+        if not local and bound_location and not source_is_master:
             # not pulling from master, so we need to update master.
             master_branch = self.target.get_master_branch(possible_transports)
             master_branch.lock_write()
@@ -3465,7 +3474,8 @@
             return self._pull(overwrite,
                 stop_revision, _hook_master=master_branch,
                 run_hooks=run_hooks,
-                _override_hook_target=_override_hook_target)
+                _override_hook_target=_override_hook_target,
+                merge_tags_to_master=not source_is_master)
         finally:
             if master_branch:
                 master_branch.unlock()
@@ -3538,7 +3548,8 @@
 
     def _pull(self, overwrite=False, stop_revision=None,
              possible_transports=None, _hook_master=None, run_hooks=True,
-             _override_hook_target=None, local=False):
+             _override_hook_target=None, local=False,
+             merge_tags_to_master=True):
         """See Branch.pull.
 
         This function is the core worker, used by GenericInterBranch.pull to
@@ -3579,7 +3590,7 @@
             # so a tags implementation that versions tags can only 
             # pull in the most recent changes. -- JRV20090506
             result.tag_conflicts = self.source.tags.merge_to(self.target.tags,
-                overwrite)
+                overwrite, ignore_master=not merge_tags_to_master)
             result.new_revno, result.new_revid = self.target.last_revision_info()
             if _hook_master:
                 result.master_branch = _hook_master

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2011-01-10 22:20:12 +0000
+++ bzrlib/builtins.py	2011-01-12 01:01:53 +0000
@@ -21,8 +21,6 @@
 from bzrlib.lazy_import import lazy_import
 lazy_import(globals(), """
 import cStringIO
-import itertools
-import re
 import sys
 import time
 
@@ -2052,7 +2050,9 @@
     @display_command
     def run(self, null=False, directory=u'.'):
         tree = WorkingTree.open_containing(directory)[0]
+        self.add_cleanup(tree.lock_read().unlock)
         td = tree.changes_from(tree.basis_tree())
+        self.cleanup_now()
         for path, id, kind, text_modified, meta_modified in td.modified:
             if null:
                 self.outf.write(path + '\0')
@@ -5482,24 +5482,17 @@
     takes_options = [
         custom_help('directory',
             help='Branch whose tags should be displayed.'),
-        RegistryOption.from_kwargs('sort',
+        RegistryOption('sort',
             'Sort tags by different criteria.', title='Sorting',
-            natural='Sort numeric substrings as numbers:'
-                    ' suitable for version numbers. (default)',
-            alpha='Sort tags lexicographically.',
-            time='Sort tags chronologically.',
+            lazy_registry=('bzrlib.tag', 'tag_sort_methods')
             ),
         'show-ids',
         'revision',
     ]
 
     @display_command
-    def run(self,
-            directory='.',
-            sort='natural',
-            show_ids=False,
-            revision=None,
-            ):
+    def run(self, directory='.', sort=None, show_ids=False, revision=None):
+        from bzrlib.tag import tag_sort_methods
         branch, relpath = Branch.open_containing(directory)
 
         tags = branch.tags.get_tag_dict().items()
@@ -5514,25 +5507,9 @@
             # only show revisions between revid1 and revid2 (inclusive)
             tags = [(tag, revid) for tag, revid in tags if
                 graph.is_between(revid, revid1, revid2)]
-        if sort == 'natural':
-            def natural_sort_key(tag):
-                return [f(s) for f,s in 
-                        zip(itertools.cycle((unicode.lower,int)),
-                                            re.split('([0-9]+)', tag[0]))]
-            tags.sort(key=natural_sort_key)
-        elif sort == 'alpha':
-            tags.sort()
-        elif sort == 'time':
-            timestamps = {}
-            for tag, revid in tags:
-                try:
-                    revobj = branch.repository.get_revision(revid)
-                except errors.NoSuchRevision:
-                    timestamp = sys.maxint # place them at the end
-                else:
-                    timestamp = revobj.timestamp
-                timestamps[revid] = timestamp
-            tags.sort(key=lambda x: timestamps[x[1]])
+        if sort is None:
+            sort = tag_sort_methods.get()
+        sort(branch, tags)
         if not show_ids:
             # [ (tag, revid), ... ] -> [ (tag, dotted_revno), ... ]
             for index, (tag, revid) in enumerate(tags):

=== modified file 'bzrlib/knit.py'
--- bzrlib/knit.py	2010-06-04 03:09:35 +0000
+++ bzrlib/knit.py	2011-01-11 20:42:36 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -54,6 +54,7 @@
 
 from cStringIO import StringIO
 from itertools import izip
+import gzip
 import operator
 import os
 import sys
@@ -1879,7 +1880,7 @@
         :return: the header and the decompressor stream.
                  as (stream, header_record)
         """
-        df = tuned_gzip.GzipFile(mode='rb', fileobj=StringIO(raw_data))
+        df = gzip.GzipFile(mode='rb', fileobj=StringIO(raw_data))
         try:
             # Current serialise
             rec = self._check_header(key, df.readline())
@@ -1894,7 +1895,7 @@
         # 4168 calls in 2880 217 internal
         # 4168 calls to _parse_record_header in 2121
         # 4168 calls to readlines in 330
-        df = tuned_gzip.GzipFile(mode='rb', fileobj=StringIO(data))
+        df = gzip.GzipFile(mode='rb', fileobj=StringIO(data))
         try:
             record_contents = df.readlines()
         except Exception, e:

=== modified file 'bzrlib/multiparent.py'
--- bzrlib/multiparent.py	2010-08-11 01:31:11 +0000
+++ bzrlib/multiparent.py	2011-01-11 18:48:11 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2010 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
     )
 from bzrlib import bencode
 """)
-from bzrlib.tuned_gzip import GzipFile
+from gzip import GzipFile
 
 
 def topo_iter_keys(vf, keys=None):
@@ -564,7 +564,8 @@
         zip_file = GzipFile(None, mode='rb', fileobj=sio)
         try:
             file_version_id = zip_file.readline()
-            return MultiParent.from_patch(zip_file.read())
+            content = zip_file.read()
+            return MultiParent.from_patch(content)
         finally:
             zip_file.close()
 

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2010-11-06 02:32:43 +0000
+++ bzrlib/osutils.py	2011-01-11 20:20:13 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -2376,3 +2376,16 @@
         counter += 1
         name = "%s.~%d~" % (base, counter)
     return name
+
+
+def set_fd_cloexec(fd):
+    """Set a Unix file descriptor's FD_CLOEXEC flag.  Do nothing if platform
+    support for this is not available.
+    """
+    try:
+        import fcntl
+        old = fcntl.fcntl(fd, fcntl.F_GETFD)
+        fcntl.fcntl(fd, fcntl.F_SETFD, old | fcntl.FD_CLOEXEC)
+    except (ImportError, AttributeError):
+        # Either the fcntl module or specific constants are not present
+        pass

=== modified file 'bzrlib/plugins/launchpad/test_register.py'
--- bzrlib/plugins/launchpad/test_register.py	2011-01-10 22:20:12 +0000
+++ bzrlib/plugins/launchpad/test_register.py	2011-01-12 01:01:53 +0000
@@ -15,18 +15,16 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 import base64
-import os
 from StringIO import StringIO
 import urlparse
 import xmlrpclib
 
 from bzrlib import (
     config,
-    osutils,
     tests,
     ui,
     )
-from bzrlib.tests import TestCaseWithTransport, TestSkipped
+from bzrlib.tests import TestCaseWithTransport
 
 # local import
 from bzrlib.plugins.launchpad.lp_registration import (
@@ -61,6 +59,25 @@
         """
         return (200, 'OK', [])
 
+    def getresponse(self, buffering=True):
+        """Fake the http reply.
+
+        This is used when running on Python 2.7, where xmlrpclib uses
+        httplib.HTTPConnection in a different way than before.
+        """
+        class FakeHttpResponse(object):
+
+            def __init__(self, status, reason, headers, body):
+                self.status = status
+                self.reason = reason
+                self.headers = headers
+                self.body = body
+
+            def read(self, size=-1):
+                return self.body.read(size)
+
+        return FakeHttpResponse(200, 'OK', [], self.getfile())
+
     def getfile(self):
         """Return a fake file containing the response content."""
         return StringIO('''\
@@ -85,6 +102,7 @@
     def __init__(self, testcase, expect_auth):
         self.testcase = testcase
         self.expect_auth = expect_auth
+        self._connection = (None, None)
 
     def make_connection(self, host):
         host, http_headers, x509 = self.get_host_info(host)

=== modified file 'bzrlib/repofmt/weaverepo.py'
--- bzrlib/repofmt/weaverepo.py	2010-11-20 21:41:05 +0000
+++ bzrlib/repofmt/weaverepo.py	2011-01-12 00:43:17 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2010 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 ghosts.
 """
 
+import gzip
 import os
 from cStringIO import StringIO
 import urllib
@@ -40,6 +41,7 @@
     lockdir,
     osutils,
     trace,
+    tuned_gzip,
     urlutils,
     versionedfile,
     weave,
@@ -56,7 +58,6 @@
     RepositoryFormat,
     )
 from bzrlib.store.text import TextStore
-from bzrlib.tuned_gzip import GzipFile, bytes_to_gzip
 from bzrlib.versionedfile import (
     AbsentContentFactory,
     FulltextContentFactory,
@@ -589,7 +590,7 @@
             raise ValueError('bad idea to put / in %r' % (key,))
         text = ''.join(lines)
         if self._compressed:
-            text = bytes_to_gzip(text)
+            text = tuned_gzip.bytes_to_gzip(text)
         path = self._map(key)
         self._transport.put_bytes_non_atomic(path, text, create_parent_dir=True)
 
@@ -637,7 +638,7 @@
             else:
                 return None
         if compressed:
-            text = GzipFile(mode='rb', fileobj=StringIO(text)).read()
+            text = gzip.GzipFile(mode='rb', fileobj=StringIO(text)).read()
         return text
 
     def _map(self, key):
@@ -743,9 +744,6 @@
 
 class InterWeaveRepo(InterSameDataRepository):
     """Optimised code paths between Weave based repositories.
-
-    This should be in bzrlib/repofmt/weaverepo.py but we have not yet
-    implemented lazy inter-object optimisation.
     """
 
     @classmethod

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2011-01-11 00:36:10 +0000
+++ bzrlib/repository.py	2011-01-12 01:01:53 +0000
@@ -2853,39 +2853,6 @@
         raise NotImplementedError(self.revision_graph_can_have_wrong_parents)
 
 
-# remove these delegates a while after bzr 0.15
-def __make_delegated(name, from_module):
-    def _deprecated_repository_forwarder():
-        symbol_versioning.warn('%s moved to %s in bzr 0.15'
-            % (name, from_module),
-            DeprecationWarning,
-            stacklevel=2)
-        try:
-            return pyutils.get_named_object(from_module, name)
-        except AttributeError:
-            raise AttributeError('module %s has no name %s'
-                    % (sys.modules[from_module], name))
-    globals()[name] = _deprecated_repository_forwarder
-
-for _name in [
-        'AllInOneRepository',
-        'WeaveMetaDirRepository',
-        'PreSplitOutRepositoryFormat',
-        'RepositoryFormat4',
-        'RepositoryFormat5',
-        'RepositoryFormat6',
-        'RepositoryFormat7',
-        ]:
-    __make_delegated(_name, 'bzrlib.repofmt.weaverepo')
-
-for _name in [
-        'KnitRepository',
-        'RepositoryFormatKnit',
-        'RepositoryFormatKnit1',
-        ]:
-    __make_delegated(_name, 'bzrlib.repofmt.knitrepo')
-
-
 def install_revision(repository, rev, revision_tree):
     """Install all revision data into a repository."""
     install_revisions(repository, [(rev, revision_tree, None)])

=== modified file 'bzrlib/tag.py'
--- bzrlib/tag.py	2010-11-18 00:30:51 +0000
+++ bzrlib/tag.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2010 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,6 +25,12 @@
 # NOTE: I was going to call this tags.py, but vim seems to think all files
 # called tags* are ctags files... mbp 20070220.
 
+from bzrlib.registry import Registry
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
+import itertools
+import re
+import sys
 
 from bzrlib import (
     bencode,
@@ -33,6 +39,7 @@
     symbol_versioning,
     trace,
     )
+""")
 
 
 class _Tags(object):
@@ -307,3 +314,50 @@
             DeprecationWarning)
         from_branch.tags.merge_to(to_branch.tags)
 
+
+def sort_natural(branch, tags):
+    """Sort tags, with numeric substrings as numbers.
+
+    :param branch: Branch
+    :param tags: List of tuples with tag name and revision id.
+    """
+    def natural_sort_key(tag):
+        return [f(s) for f,s in
+                zip(itertools.cycle((unicode.lower,int)),
+                                    re.split('([0-9]+)', tag[0]))]
+    tags.sort(key=natural_sort_key)
+
+
+def sort_alpha(branch, tags):
+    """Sort tags lexicographically, in place.
+
+    :param branch: Branch
+    :param tags: List of tuples with tag name and revision id.
+    """
+    tags.sort()
+
+
+def sort_time(branch, tags):
+    """Sort tags by time inline.
+
+    :param branch: Branch
+    :param tags: List of tuples with tag name and revision id.
+    """
+    timestamps = {}
+    for tag, revid in tags:
+        try:
+            revobj = branch.repository.get_revision(revid)
+        except errors.NoSuchRevision:
+            timestamp = sys.maxint # place them at the end
+        else:
+            timestamp = revobj.timestamp
+        timestamps[revid] = timestamp
+    tags.sort(key=lambda x: timestamps[x[1]])
+
+
+tag_sort_methods = Registry()
+tag_sort_methods.register("natural", sort_natural,
+    'Sort numeric substrings as numbers. (default)')
+tag_sort_methods.register("alpha", sort_alpha, 'Sort tags lexicographically.')
+tag_sort_methods.register("time", sort_time, 'Sort tags chronologically.')
+tag_sort_methods.default_key = "natural"

=== modified file 'bzrlib/tests/EncodingAdapter.py'
--- bzrlib/tests/EncodingAdapter.py	2010-05-24 01:05:14 +0000
+++ bzrlib/tests/EncodingAdapter.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2009, 2010 Canonical Ltd
+# Copyright (C) 2006, 2009, 2010, 2011 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify
@@ -17,8 +17,6 @@
 
 """Adapter for running test cases against multiple encodings."""
 
-from copy import deepcopy
-
 # prefix for micro (1/1000000)
 _mu = u'\xb5'
 

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/__init__.py	2011-01-12 01:01:53 +0000
@@ -123,6 +123,93 @@
 TestSuite = TestUtil.TestSuite
 TestLoader = TestUtil.TestLoader
 
+# Tests should run in a clean and clearly defined environment. The goal is to
+# keep them isolated from the running environment as mush as possible. The test
+# framework ensures the variables defined below are set (or deleted if the
+# value is None) before a test is run and reset to their original value after
+# the test is run. Generally if some code depends on an environment variable,
+# the tests should start without this variable in the environment. There are a
+# few exceptions but you shouldn't violate this rule lightly.
+isolated_environ = {
+    'BZR_HOME': None,
+    'HOME': None,
+    # bzr now uses the Win32 API and doesn't rely on APPDATA, but the
+    # tests do check our impls match APPDATA
+    'BZR_EDITOR': None, # test_msgeditor manipulates this variable
+    'VISUAL': None,
+    'EDITOR': None,
+    'BZR_EMAIL': None,
+    'BZREMAIL': None, # may still be present in the environment
+    'EMAIL': 'jrandom@example.com', # set EMAIL as bzr does not guess
+    'BZR_PROGRESS_BAR': None,
+    'BZR_LOG': None,
+    'BZR_PLUGIN_PATH': None,
+    'BZR_DISABLE_PLUGINS': None,
+    'BZR_PLUGINS_AT': None,
+    'BZR_CONCURRENCY': None,
+    # Make sure that any text ui tests are consistent regardless of
+    # the environment the test case is run in; you may want tests that
+    # test other combinations.  'dumb' is a reasonable guess for tests
+    # going to a pipe or a StringIO.
+    'TERM': 'dumb',
+    'LINES': '25',
+    'COLUMNS': '80',
+    'BZR_COLUMNS': '80',
+    # Disable SSH Agent
+    'SSH_AUTH_SOCK': None,
+    # Proxies
+    'http_proxy': None,
+    'HTTP_PROXY': None,
+    'https_proxy': None,
+    'HTTPS_PROXY': None,
+    'no_proxy': None,
+    'NO_PROXY': None,
+    'all_proxy': None,
+    'ALL_PROXY': None,
+    # Nobody cares about ftp_proxy, FTP_PROXY AFAIK. So far at
+    # least. If you do (care), please update this comment
+    # -- vila 20080401
+    'ftp_proxy': None,
+    'FTP_PROXY': None,
+    'BZR_REMOTE_PATH': None,
+    # Generally speaking, we don't want apport reporting on crashes in
+    # the test envirnoment unless we're specifically testing apport,
+    # so that it doesn't leak into the real system environment.  We
+    # use an env var so it propagates to subprocesses.
+    'APPORT_DISABLE': '1',
+    }
+
+
+def override_os_environ(test, env=None):
+    """Modify os.environ keeping a copy.
+    
+    :param test: A test instance
+
+    :param env: A dict containing variable definitions to be installed
+    """
+    if env is None:
+        env = isolated_environ
+    test._original_os_environ = dict([(var, value)
+                                      for var, value in os.environ.iteritems()])
+    for var, value in env.iteritems():
+        osutils.set_or_unset_env(var, value)
+        if var not in test._original_os_environ:
+            # The var is new, add it with a value of None, so
+            # restore_os_environ will delete it
+            test._original_os_environ[var] = None
+
+
+def restore_os_environ(test):
+    """Restore os.environ to its original state.
+
+    :param test: A test instance previously passed to override_os_environ.
+    """
+    for var, value in test._original_os_environ.iteritems():
+        # Restore the original value (or delete it if the value has been set to
+        # None in override_os_environ).
+        osutils.set_or_unset_env(var, value)
+
+
 class ExtendedTestResult(testtools.TextTestResult):
     """Accepts, reports and accumulates the results of running tests.
 
@@ -794,6 +881,25 @@
         return NullProgressView()
 
 
+def isolated_doctest_setUp(test):
+    override_os_environ(test)
+
+
+def isolated_doctest_tearDown(test):
+    restore_os_environ(test)
+
+
+def IsolatedDocTestSuite(*args, **kwargs):
+    """Overrides doctest.DocTestSuite to handle isolation.
+
+    The method is really a factory and users are expected to use it as such.
+    """
+    
+    kwargs['setUp'] = isolated_doctest_setUp
+    kwargs['tearDown'] = isolated_doctest_tearDown
+    return doctest.DocTestSuite(*args, **kwargs)
+
+
 class TestCase(testtools.TestCase):
     """Base class for bzr unit tests.
 
@@ -835,7 +941,6 @@
         self.addDetail("log", content.Content(content.ContentType("text",
             "plain", {"charset": "utf8"}),
             lambda:[self._get_log(keep_log_file=True)]))
-        self._old_env = {}
         self._cleanEnvironment()
         self._silenceUI()
         self._startLogFile()
@@ -1538,61 +1643,9 @@
         return value
 
     def _cleanEnvironment(self):
-        new_env = {
-            'BZR_HOME': None, # Don't inherit BZR_HOME to all the tests.
-            'HOME': os.getcwd(),
-            # bzr now uses the Win32 API and doesn't rely on APPDATA, but the
-            # tests do check our impls match APPDATA
-            'BZR_EDITOR': None, # test_msgeditor manipulates this variable
-            'VISUAL': None,
-            'EDITOR': None,
-            'BZR_EMAIL': None,
-            'BZREMAIL': None, # may still be present in the environment
-            'EMAIL': 'jrandom@example.com', # set EMAIL as bzr does not guess
-            'BZR_PROGRESS_BAR': None,
-            'BZR_LOG': None,
-            'BZR_PLUGIN_PATH': None,
-            'BZR_DISABLE_PLUGINS': None,
-            'BZR_PLUGINS_AT': None,
-            'BZR_CONCURRENCY': None,
-            # Make sure that any text ui tests are consistent regardless of
-            # the environment the test case is run in; you may want tests that
-            # test other combinations.  'dumb' is a reasonable guess for tests
-            # going to a pipe or a StringIO.
-            'TERM': 'dumb',
-            'LINES': '25',
-            'COLUMNS': '80',
-            'BZR_COLUMNS': '80',
-            # SSH Agent
-            'SSH_AUTH_SOCK': None,
-            # Proxies
-            'http_proxy': None,
-            'HTTP_PROXY': None,
-            'https_proxy': None,
-            'HTTPS_PROXY': None,
-            'no_proxy': None,
-            'NO_PROXY': None,
-            'all_proxy': None,
-            'ALL_PROXY': None,
-            # Nobody cares about ftp_proxy, FTP_PROXY AFAIK. So far at
-            # least. If you do (care), please update this comment
-            # -- vila 20080401
-            'ftp_proxy': None,
-            'FTP_PROXY': None,
-            'BZR_REMOTE_PATH': None,
-            # Generally speaking, we don't want apport reporting on crashes in
-            # the test envirnoment unless we're specifically testing apport,
-            # so that it doesn't leak into the real system environment.  We
-            # use an env var so it propagates to subprocesses.
-            'APPORT_DISABLE': '1',
-        }
-        for name, value in new_env.iteritems():
+        for name, value in isolated_environ.iteritems():
             self.overrideEnv(name, value)
 
-    def _captureVar(self, name, newvalue):
-        """Set an environment variable, and reset it when finished."""
-        self._old_env[name] = osutils.set_or_unset_env(name, newvalue)
-
     def _restoreHooks(self):
         for klass, (name, hooks) in self._preserved_hooks.items():
             setattr(klass, name, hooks)
@@ -3836,13 +3889,7 @@
         return []
     return [
         'bzrlib',
-        # FIXME: Fixing bug #690563 revealed an isolation problem in the single
-        # doctest for branchbuilder. Uncomment this when bug #321320 is fixed
-        # to ensure the issue is addressed (note that to reproduce the bug in
-        # the doctest below, one should comment the 'email' config var in
-        # bazaar.conf (or anywhere else). This means an setup where *no* user
-        # is being set at all in the environment.
-#       'bzrlib.branchbuilder',
+        'bzrlib.branchbuilder',
         'bzrlib.decorators',
         'bzrlib.export',
         'bzrlib.inventory',
@@ -3914,8 +3961,8 @@
         try:
             # note that this really does mean "report only" -- doctest
             # still runs the rest of the examples
-            doc_suite = doctest.DocTestSuite(mod,
-                optionflags=doctest.REPORT_ONLY_FIRST_FAILURE)
+            doc_suite = IsolatedDocTestSuite(
+                mod, optionflags=doctest.REPORT_ONLY_FIRST_FAILURE)
         except ValueError, e:
             print '**failed to get doctest for: %s\n%s' % (mod, e)
             raise

=== modified file 'bzrlib/tests/blackbox/test_exceptions.py'
--- bzrlib/tests/blackbox/test_exceptions.py	2010-11-06 15:32:00 +0000
+++ bzrlib/tests/blackbox/test_exceptions.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2007, 2009, 2010 Canonical Ltd
+# Copyright (C) 2006, 2007, 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,8 +16,6 @@
 
 """Tests for display of exceptions."""
 
-from cStringIO import StringIO
-import os
 import sys
 
 from bzrlib import (
@@ -27,11 +25,9 @@
     osutils,
     repository,
     tests,
-    trace,
     )
 
-from bzrlib.tests import TestCaseInTempDir, TestCase
-from bzrlib.errors import NotBranchError
+from bzrlib.tests import TestCase
 
 
 class TestExceptionReporting(TestCase):

=== modified file 'bzrlib/tests/blackbox/test_tags.py'
--- bzrlib/tests/blackbox/test_tags.py	2010-11-18 00:22:24 +0000
+++ bzrlib/tests/blackbox/test_tags.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2010 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -278,6 +278,40 @@
             error_regexes=["bzr: ERROR: Requested revision: '123.123' "
                 "does not exist in branch:"])
 
+    def test_sort_tags_custom(self):
+        def sort_by_dots(branch, tags):
+            def sort_key((tag, revid)):
+                return tag.count(".")
+            tags.sort(key=sort_key)
+
+        # Register a custom sort method
+        tag.tag_sort_methods.register("dots", sort_by_dots, "Sort by dots.")
+        self.addCleanup(tag.tag_sort_methods.remove, "dots")
+
+        tree1 = self.make_branch_and_tree('branch1')
+        tree1.commit(allow_pointless=True, message='revision 1',
+                rev_id='revid-1', timestamp=10)
+        tree1.commit(allow_pointless=True, message='revision 2',
+                rev_id='revid-2', timestamp=15)
+
+        b1 = tree1.branch
+
+        b1.tags.set_tag(u'tag..', 'revid-2')
+        b1.tags.set_tag(u'tag....', 'missing') # not present in repository
+        b1.tags.set_tag(u'tag.', 'revid-1')
+        b1.tags.set_tag(u'tag...', 'revid-1')
+        b1.tags.set_tag(u'tag....', 'revid-1')
+
+        # sorted by number of dots
+        out, err = self.run_bzr('tags --sort=dots -d branch1')
+        self.assertEquals(err, '')
+        self.assertEquals([
+            'tag.                 1',
+            'tag..                2',
+            'tag...               1',
+            'tag....              1'],
+            out.splitlines())
+
     def _check_tag_filter(self, argstr, expected_revnos):
         #upper bound of laziness
         out, err = self.run_bzr('tags ' + argstr)

=== modified file 'bzrlib/tests/features.py'
--- bzrlib/tests/features.py	2010-10-11 09:53:16 +0000
+++ bzrlib/tests/features.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 Canonical Ltd
+# Copyright (C) 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 import stat
 
 from bzrlib import tests
-from bzrlib.symbol_versioning import deprecated_in
 
 
 class _NotRunningAsRoot(tests.Feature):

=== modified file 'bzrlib/tests/http_server.py'
--- bzrlib/tests/http_server.py	2010-08-24 13:01:06 +0000
+++ bzrlib/tests/http_server.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,23 +20,12 @@
 import posixpath
 import random
 import re
-import select
 import SimpleHTTPServer
 import socket
-import SocketServer
-import sys
-import threading
-import time
 import urllib
 import urlparse
 
-from bzrlib import (
-    osutils,
-    tests,
-    transport,
-    )
 from bzrlib.tests import test_server
-from bzrlib.transport import local
 
 
 class BadWebserverPath(ValueError):

=== modified file 'bzrlib/tests/http_utils.py'
--- bzrlib/tests/http_utils.py	2010-06-23 16:43:16 +0000
+++ bzrlib/tests/http_utils.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,13 +15,8 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 from cStringIO import StringIO
-import errno
 import re
-import socket
-import threading
-import time
 import urllib2
-import urlparse
 
 
 from bzrlib import (
@@ -32,7 +27,6 @@
     )
 from bzrlib.smart import (
     medium,
-    protocol,
     )
 from bzrlib.tests import http_server
 from bzrlib.transport import chroot

=== modified file 'bzrlib/tests/per_branch/test_update.py'
--- bzrlib/tests/per_branch/test_update.py	2010-02-10 17:52:08 +0000
+++ bzrlib/tests/per_branch/test_update.py	2011-01-10 21:31:59 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,8 +16,10 @@
 
 
 from bzrlib import (
+    branch,
     errors,
     revision as _mod_revision,
+    tests,
     )
 from bzrlib.tests import per_branch
 
@@ -115,3 +117,23 @@
 
         tree1.branch.update_revisions(tree2.branch, overwrite=True)
         self.assertEqual((1, rev1), tree1.branch.last_revision_info())
+
+    def test_update_in_checkout_of_readonly(self):
+        tree1 = self.make_branch_and_tree('tree1')
+        rev1 = tree1.commit('one')
+        try:
+            tree1.branch.tags.set_tag('test-tag', rev1)
+        except errors.TagsNotSupported:
+            # Tags not supported
+            raise tests.TestNotApplicable("only triggered from branches with"
+                " tags")
+        readonly_branch1 = branch.Branch.open('readonly+' + tree1.branch.base)
+        tree2 = tree1.bzrdir.sprout('tree2').open_workingtree()
+        try:
+            tree2.branch.bind(readonly_branch1)
+        except errors.UpgradeRequired:
+            # old branch, cant test.
+            raise tests.TestNotApplicable("only triggered in bound branches")
+        rev2 = tree1.commit('two')
+        tree2.update()
+        self.assertEqual(rev2, tree2.branch.last_revision())

=== modified file 'bzrlib/tests/per_controldir/test_controldir.py'
--- bzrlib/tests/per_controldir/test_controldir.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/per_controldir/test_controldir.py	2011-01-12 01:01:53 +0000
@@ -17,7 +17,6 @@
 """Tests for control directory implementations - tests a controldir format."""
 
 from itertools import izip
-import os
 
 import bzrlib.branch
 from bzrlib import (

=== modified file 'bzrlib/tests/per_interrepository/test_interrepository.py'
--- bzrlib/tests/per_interrepository/test_interrepository.py	2009-07-10 06:46:10 +0000
+++ bzrlib/tests/per_interrepository/test_interrepository.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2007, 2008 Canonical Ltd
+# Copyright (C) 2006-2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,17 +19,12 @@
 import sys
 
 import bzrlib
-import bzrlib.bzrdir as bzrdir
-from bzrlib.branch import Branch, needs_read_lock, needs_write_lock
 import bzrlib.errors as errors
 import bzrlib.gpg
 from bzrlib.inventory import Inventory
 import bzrlib.repofmt.weaverepo as weaverepo
-import bzrlib.repository as repository
-from bzrlib.revision import NULL_REVISION, Revision
+from bzrlib.revision import NULL_REVISION
 from bzrlib.tests import (
-    TestCase,
-    TestCaseWithTransport,
     TestNotApplicable,
     TestSkipped,
     )
@@ -67,7 +62,7 @@
     if (isinstance(repo, (weaverepo.AllInOneRepository,
                           weaverepo.WeaveMetaDirRepository))
         and sys.platform == 'win32'):
-            raise TestSkipped("funky chars does not permitted"
+            raise TestSkipped("funky chars not allowed"
                               " on this platform in repository"
                               " %s" % repo.__class__.__name__)
 

=== modified file 'bzrlib/tests/per_merger.py'
--- bzrlib/tests/per_merger.py	2010-03-05 08:55:12 +0000
+++ bzrlib/tests/per_merger.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 Canonical Ltd
+# Copyright (C) 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
     errors,
     merge as _mod_merge,
     option,
-    progress,
     )
 from bzrlib.tests import (
     multiply_tests,

=== modified file 'bzrlib/tests/per_pack_repository.py'
--- bzrlib/tests/per_pack_repository.py	2010-05-06 23:41:35 +0000
+++ bzrlib/tests/per_pack_repository.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2008, 2009, 2010 Canonical Ltd
+# Copyright (C) 2008-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 These tests are repeated for all pack-based repository formats.
 """
 
-from cStringIO import StringIO
 from stat import S_ISDIR
 
 from bzrlib.btree_index import BTreeGraphIndex
@@ -29,35 +28,24 @@
     errors,
     inventory,
     osutils,
-    progress,
     repository,
     revision as _mod_revision,
-    symbol_versioning,
     tests,
     ui,
-    upgrade,
-    workingtree,
-    )
-from bzrlib.repofmt import (
-    pack_repo,
-    groupcompress_repo,
     )
 from bzrlib.repofmt.groupcompress_repo import RepositoryFormat2a
 from bzrlib.smart import (
     client,
     )
 from bzrlib.tests import (
-    TestCase,
     TestCaseWithTransport,
     TestNotApplicable,
-    TestSkipped,
     )
 from bzrlib.transport import (
     get_transport,
     memory,
     )
 from bzrlib.tests import test_server
-from bzrlib.tests.per_repository import TestCaseWithRepository
 
 
 class TestPackRepository(TestCaseWithTransport):

=== modified file 'bzrlib/tests/per_repository/test_repository.py'
--- bzrlib/tests/per_repository/test_repository.py	2010-05-06 23:41:35 +0000
+++ bzrlib/tests/per_repository/test_repository.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,10 +25,8 @@
     delta as _mod_delta,
     errors,
     gpg,
-    graph,
     info,
     inventory,
-    osutils,
     remote,
     repository,
     revision as _mod_revision,
@@ -37,7 +35,6 @@
     upgrade,
     versionedfile,
     workingtree,
-    xml_serializer,
     )
 from bzrlib.repofmt import (
     pack_repo,
@@ -854,9 +851,6 @@
 
     def test_sprout_from_hpss_preserves_format(self):
         """repo.sprout from a smart server preserves the repository format."""
-        if self.repository_format == weaverepo.RepositoryFormat7():
-            raise tests.TestNotApplicable(
-                "Cannot fetch weaves over smart protocol.")
         remote_repo = self.make_remote_repository('remote')
         local_bzrdir = self.make_bzrdir('local')
         try:

=== modified file 'bzrlib/tests/per_versionedfile.py'
--- bzrlib/tests/per_versionedfile.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/per_versionedfile.py	2011-01-12 01:01:53 +0000
@@ -21,6 +21,7 @@
 # TODO: might be nice to create a versionedfile with some type of corruption
 # considered typical and check that it can be detected/corrected.
 
+from gzip import GzipFile
 from itertools import chain, izip
 from StringIO import StringIO
 
@@ -37,14 +38,11 @@
 from bzrlib.errors import (
                            RevisionNotPresent,
                            RevisionAlreadyPresent,
-                           WeaveParentMismatch
                            )
 from bzrlib.knit import (
     cleanup_pack_knit,
     make_file_factory,
     make_pack_factory,
-    KnitAnnotateFactory,
-    KnitPlainFactory,
     )
 from bzrlib.tests import (
     TestCase,
@@ -53,10 +51,7 @@
     TestSkipped,
     )
 from bzrlib.tests.http_utils import TestCaseWithWebserver
-from bzrlib.trace import mutter
 from bzrlib.transport.memory import MemoryTransport
-from bzrlib.tsort import topo_sort
-from bzrlib.tuned_gzip import GzipFile
 import bzrlib.versionedfile as versionedfile
 from bzrlib.versionedfile import (
     ConstantMapper,
@@ -66,7 +61,7 @@
     make_versioned_files_factory,
     )
 from bzrlib.weave import WeaveFile
-from bzrlib.weavefile import read_weave, write_weave
+from bzrlib.weavefile import write_weave
 from bzrlib.tests.scenarios import load_tests_apply_scenarios
 
 

=== modified file 'bzrlib/tests/per_workingtree/test_add_reference.py'
--- bzrlib/tests/per_workingtree/test_add_reference.py	2009-07-10 07:14:02 +0000
+++ bzrlib/tests/per_workingtree/test_add_reference.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2007 Canonical Ltd
+# Copyright (C) 2006-2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,13 +16,9 @@
 
 import os
 
-from bzrlib import errors, tests, workingtree, workingtree_4
+from bzrlib import errors, tests, workingtree
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 
-TREES_NOT_SUPPORTING_REFERENCES = (workingtree.WorkingTree2,
-                                   workingtree.WorkingTree3,
-                                   workingtree_4.WorkingTree4)
-
 
 class TestBasisInventory(TestCaseWithWorkingTree):
 
@@ -37,7 +33,7 @@
         return tree, sub_tree
 
     def _references_unsupported(self, tree):
-        if tree.__class__ in TREES_NOT_SUPPORTING_REFERENCES:
+        if not tree.supports_tree_reference():
             raise tests.TestSkipped('Tree format does not support references')
         else:
             self.fail('%r does not support references but should'

=== modified file 'bzrlib/tests/per_workingtree/test_workingtree.py'
--- bzrlib/tests/per_workingtree/test_workingtree.py	2010-11-26 17:59:08 +0000
+++ bzrlib/tests/per_workingtree/test_workingtree.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 # Authors:  Robert Collins <robert.collins@canonical.com>
 #           and others
 #
@@ -19,7 +19,6 @@
 from cStringIO import StringIO
 import errno
 import os
-import sys
 
 from bzrlib import (
     branch,
@@ -29,17 +28,22 @@
     osutils,
     tests,
     urlutils,
-    workingtree,
-    )
-from bzrlib.errors import (NotBranchError, NotVersionedError,
-                           UnsupportedOperation, PathsNotVersionedError)
+    )
+from bzrlib.errors import (
+    UnsupportedOperation,
+    PathsNotVersionedError,
+    )
 from bzrlib.inventory import Inventory
 from bzrlib.osutils import pathjoin, getcwd, has_symlinks
 from bzrlib.tests import TestSkipped, TestNotApplicable
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
-from bzrlib.trace import mutter
-from bzrlib.workingtree import (TreeEntry, TreeDirectory, TreeFile, TreeLink,
-                                WorkingTree, WorkingTree2)
+from bzrlib.workingtree import (
+    TreeDirectory,
+    TreeFile,
+    TreeLink,
+    WorkingTree,
+    WorkingTree2,
+    )
 from bzrlib.conflicts import ConflictList, TextConflict, ContentsConflict
 
 

=== modified file 'bzrlib/tests/script.py'
--- bzrlib/tests/script.py	2010-11-08 09:58:04 +0000
+++ bzrlib/tests/script.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 Canonical Ltd
+# Copyright (C) 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,10 +25,8 @@
 import os
 import shlex
 import textwrap
-from cStringIO import StringIO
 
 from bzrlib import (
-    errors,
     osutils,
     tests,
     )

=== modified file 'bzrlib/tests/stub_sftp.py'
--- bzrlib/tests/stub_sftp.py	2010-09-02 19:19:54 +0000
+++ bzrlib/tests/stub_sftp.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2008, 2009, 2010 Robey Pointer <robey@lag.net>, Canonical Ltd
+# Copyright (C) 2005, 2006, 2008-2011 Robey Pointer <robey@lag.net>, Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,11 +21,9 @@
 
 import os
 import paramiko
-import select
 import socket
 import SocketServer
 import sys
-import threading
 import time
 
 from bzrlib import (

=== modified file 'bzrlib/tests/test__annotator.py'
--- bzrlib/tests/test__annotator.py	2010-02-17 17:11:16 +0000
+++ bzrlib/tests/test__annotator.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 Canonical Ltd
+# Copyright (C) 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 
 from bzrlib import (
     annotate,
-    _annotator_py,
     errors,
     knit,
     revision,

=== modified file 'bzrlib/tests/test__chk_map.py'
--- bzrlib/tests/test__chk_map.py	2010-05-11 10:45:26 +0000
+++ bzrlib/tests/test__chk_map.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 Canonical Ltd
+# Copyright (C) 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 
 from bzrlib import (
     chk_map,
-    inventory,
     tests,
     )
 from bzrlib.static_tuple import StaticTuple

=== modified file 'bzrlib/tests/test__groupcompress.py'
--- bzrlib/tests/test__groupcompress.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test__groupcompress.py	2011-01-12 01:01:53 +0000
@@ -17,13 +17,11 @@
 """Tests for the python and pyrex extensions of groupcompress"""
 
 from bzrlib import (
-    groupcompress,
     _groupcompress_py,
     tests,
     )
 from bzrlib.tests.scenarios import (
     load_tests_apply_scenarios,
-    multiply_scenarios,
     )
 
 

=== modified file 'bzrlib/tests/test__known_graph.py'
--- bzrlib/tests/test__known_graph.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test__known_graph.py	2011-01-12 01:01:53 +0000
@@ -20,7 +20,6 @@
 
 from bzrlib import (
     errors,
-    graph as _mod_graph,
     _known_graph_py,
     tests,
     )

=== modified file 'bzrlib/tests/test__simple_set.py'
--- bzrlib/tests/test__simple_set.py	2010-08-02 19:20:30 +0000
+++ bzrlib/tests/test__simple_set.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 Canonical Ltd
+# Copyright (C) 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,8 +19,6 @@
 import sys
 
 from bzrlib import (
-    errors,
-    osutils,
     tests,
     )
 

=== modified file 'bzrlib/tests/test__static_tuple.py'
--- bzrlib/tests/test__static_tuple.py	2010-02-23 07:43:11 +0000
+++ bzrlib/tests/test__static_tuple.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 Canonical Ltd
+# Copyright (C) 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,13 +17,11 @@
 """Tests for the StaticTuple type."""
 
 import cPickle
-import gc
 import sys
 
 from bzrlib import (
     _static_tuple_py,
     debug,
-    errors,
     osutils,
     static_tuple,
     tests,

=== modified file 'bzrlib/tests/test_ancestry.py'
--- bzrlib/tests/test_ancestry.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_ancestry.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2007 Canonical Ltd
+# Copyright (C) 2005-2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,12 +15,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
-from cStringIO import StringIO
-import os
-import sys
-
 from bzrlib.tests import TestCaseWithMemoryTransport
-from bzrlib.branch import Branch
 from bzrlib.branchbuilder import BranchBuilder
 
 

=== modified file 'bzrlib/tests/test_annotate.py'
--- bzrlib/tests/test_annotate.py	2009-07-10 07:43:15 +0000
+++ bzrlib/tests/test_annotate.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Canonical Ltd
+# Copyright (C) 2006-2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,10 +21,7 @@
 
 from bzrlib import (
     annotate,
-    conflicts,
-    errors,
     tests,
-    trace,
     )
 
 

=== modified file 'bzrlib/tests/test_bad_files.py'
--- bzrlib/tests/test_bad_files.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_bad_files.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2007 Canonical Ltd
+# Copyright (C) 2005, 2006, 2007, 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 import os
 
 from bzrlib import (
-    add,
     errors,
     )
 from bzrlib.status import show_tree_status

=== modified file 'bzrlib/tests/test_bisect_multi.py'
--- bzrlib/tests/test_bisect_multi.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_bisect_multi.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Canonical Ltd
+# Copyright (C) 2007, 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
 
 """Tests for bisect_multi."""
 
-from bzrlib import errors
 from bzrlib.bisect_multi import bisect_multi_bytes
 from bzrlib.tests import TestCase
 

=== modified file 'bzrlib/tests/test_branchbuilder.py'
--- bzrlib/tests/test_branchbuilder.py	2010-11-18 08:13:01 +0000
+++ bzrlib/tests/test_branchbuilder.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007, 2009 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 
 from bzrlib import (
     branch as _mod_branch,
-    errors,
     revision as _mod_revision,
     tests,
     )

=== modified file 'bzrlib/tests/test_bundle.py'
--- bzrlib/tests/test_bundle.py	2010-08-05 04:21:03 +0000
+++ bzrlib/tests/test_bundle.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,6 @@
     inventory,
     merge,
     osutils,
-    repository,
     revision as _mod_revision,
     tests,
     treebuilder,
@@ -35,13 +34,11 @@
 from bzrlib.bundle import read_mergeable_from_url
 from bzrlib.bundle.apply_bundle import install_bundle, merge_bundle
 from bzrlib.bundle.bundle_data import BundleTree
-from bzrlib.bzrdir import BzrDir
 from bzrlib.directory_service import directories
 from bzrlib.bundle.serializer import write_bundle, read_bundle, v09, v4
 from bzrlib.bundle.serializer.v08 import BundleSerializerV08
 from bzrlib.bundle.serializer.v09 import BundleSerializerV09
 from bzrlib.bundle.serializer.v4 import BundleSerializerV4
-from bzrlib.branch import Branch
 from bzrlib.repofmt import knitrepo
 from bzrlib.tests import (
     test_read_bundle,

=== modified file 'bzrlib/tests/test_chk_serializer.py'
--- bzrlib/tests/test_chk_serializer.py	2009-06-04 21:50:04 +0000
+++ bzrlib/tests/test_chk_serializer.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009 Canonical Ltd
+# Copyright (C) 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,13 +14,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from cStringIO import StringIO
-
-from bzrlib import (
-    errors,
-    revision,
-    serializer,
-    )
 from bzrlib.chk_serializer import (
     chk_bencode_serializer,
     )

=== modified file 'bzrlib/tests/test_clean_tree.py'
--- bzrlib/tests/test_clean_tree.py	2010-08-23 17:54:07 +0000
+++ bzrlib/tests/test_clean_tree.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 Canonical Ltd
+# Copyright (C) 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 import errno
 import os
 import shutil
-from StringIO import StringIO
 import sys
 import types
 

=== modified file 'bzrlib/tests/test_commands.py'
--- bzrlib/tests/test_commands.py	2010-08-28 16:56:36 +0000
+++ bzrlib/tests/test_commands.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from cStringIO import StringIO
 import errno
 import inspect
 import sys

=== modified file 'bzrlib/tests/test_commit.py'
--- bzrlib/tests/test_commit.py	2010-10-15 16:43:03 +0000
+++ bzrlib/tests/test_commit.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,18 +21,14 @@
 from bzrlib import (
     bzrdir,
     errors,
-    lockdir,
-    osutils,
-    tests,
     )
 from bzrlib.branch import Branch
-from bzrlib.bzrdir import BzrDir, BzrDirMetaFormat1
+from bzrlib.bzrdir import BzrDirMetaFormat1
 from bzrlib.commit import Commit, NullCommitReporter
 from bzrlib.config import BranchConfig
 from bzrlib.errors import (PointlessCommit, BzrError, SigningFailed,
                            LockContention)
 from bzrlib.tests import SymlinkFeature, TestCaseWithTransport
-from bzrlib.workingtree import WorkingTree
 
 
 # TODO: Test commit with some added, and added-but-missing files

=== modified file 'bzrlib/tests/test_commit_merge.py'
--- bzrlib/tests/test_commit_merge.py	2009-08-05 02:30:59 +0000
+++ bzrlib/tests/test_commit_merge.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 Canonical Ltd
+# Copyright (C) 2005, 2006, 2007, 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,16 +16,13 @@
 
 
 import os
-import shutil
 
 from bzrlib import check, osutils
-from bzrlib.branch import Branch
-from bzrlib.errors import PointlessCommit, BzrError
+from bzrlib.errors import PointlessCommit
 from bzrlib.tests import (
     SymlinkFeature,
     TestCaseWithTransport,
     )
-from bzrlib.tests.test_revision import make_branches
 
 
 class TestCommitMerge(TestCaseWithTransport):

=== modified file 'bzrlib/tests/test_conflicts.py'
--- bzrlib/tests/test_conflicts.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_conflicts.py	2011-01-12 01:01:53 +0000
@@ -18,13 +18,11 @@
 import os
 
 from bzrlib import (
-    branchbuilder,
     bzrdir,
     conflicts,
     errors,
     option,
     tests,
-    workingtree,
     )
 from bzrlib.tests import (
     script,

=== modified file 'bzrlib/tests/test_crash.py'
--- bzrlib/tests/test_crash.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_crash.py	2011-01-12 01:01:53 +0000
@@ -26,7 +26,6 @@
     config,
     crash,
     osutils,
-    symbol_versioning,
     tests,
     )
 

=== modified file 'bzrlib/tests/test_dirstate.py'
--- bzrlib/tests/test_dirstate.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_dirstate.py	2011-01-12 01:01:53 +0000
@@ -16,7 +16,6 @@
 
 """Tests of the dirstate functionality being built for WorkingTreeFormat4."""
 
-import bisect
 import os
 
 from bzrlib import (

=== modified file 'bzrlib/tests/test_eol_filters.py'
--- bzrlib/tests/test_eol_filters.py	2009-06-10 23:29:48 +0000
+++ bzrlib/tests/test_eol_filters.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009 Canonical Ltd
+# Copyright (C) 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 
 from bzrlib import (
     errors,
-    rules,
     )
 from bzrlib.filters import _get_filter_stack_for
 from bzrlib.filters.eol import (

=== modified file 'bzrlib/tests/test_errors.py'
--- bzrlib/tests/test_errors.py	2010-12-02 09:23:10 +0000
+++ bzrlib/tests/test_errors.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,10 +25,13 @@
     bzrdir,
     errors,
     osutils,
-    symbol_versioning,
     urlutils,
     )
-from bzrlib.tests import TestCase, TestCaseWithTransport, TestSkipped
+from bzrlib.tests import (
+    TestCase,
+    TestCaseWithTransport,
+    TestSkipped,
+    )
 
 
 class TestErrors(TestCaseWithTransport):

=== modified file 'bzrlib/tests/test_extract.py'
--- bzrlib/tests/test_extract.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_extract.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Canonical Ltd
+# Copyright (C) 2006, 2007, 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
 
 from bzrlib import (
     branch,
-    bzrdir,
     errors,
     )
 from bzrlib.tests import TestCaseWithTransport

=== modified file 'bzrlib/tests/test_fetch.py'
--- bzrlib/tests/test_fetch.py	2010-02-09 20:18:32 +0000
+++ bzrlib/tests/test_fetch.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2007, 2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,25 +14,16 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-import os
-import re
-import sys
-
-import bzrlib
 from bzrlib import (
     bzrdir,
     errors,
     osutils,
-    merge,
-    repository,
     versionedfile,
     )
 from bzrlib.branch import Branch
-from bzrlib.bzrdir import BzrDir
 from bzrlib.repofmt import knitrepo
 from bzrlib.tests import TestCaseWithTransport
 from bzrlib.tests.test_revision import make_branches
-from bzrlib.trace import mutter
 from bzrlib.upgrade import Convert
 from bzrlib.workingtree import WorkingTree
 

=== modified file 'bzrlib/tests/test_ftp_transport.py'
--- bzrlib/tests/test_ftp_transport.py	2010-02-27 01:34:49 +0000
+++ bzrlib/tests/test_ftp_transport.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2010 Canonical Ltd
+# Copyright (C) 2006, 2007, 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,10 +14,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from cStringIO import StringIO
 import ftplib
 import getpass
-import sys
 
 from bzrlib import (
     config,

=== modified file 'bzrlib/tests/test_generate_docs.py'
--- bzrlib/tests/test_generate_docs.py	2009-06-19 09:06:56 +0000
+++ bzrlib/tests/test_generate_docs.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Canonical Ltd
+# Copyright (C) 2007, 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 from cStringIO import StringIO
 
 import bzrlib.commands
-from bzrlib.tests import TestCase, TestSkipped
+from bzrlib.tests import TestCase
 
 
 class Options:

=== modified file 'bzrlib/tests/test_generate_ids.py'
--- bzrlib/tests/test_generate_ids.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_generate_ids.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Canonical Ltd
+# Copyright (C) 2006, 2007, 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,8 +16,6 @@
 
 """Tests for bzrlib/generate_ids.py"""
 
-import re
-
 from bzrlib import (
     generate_ids,
     tests,

=== modified file 'bzrlib/tests/test_globbing.py'
--- bzrlib/tests/test_globbing.py	2010-08-07 16:42:09 +0000
+++ bzrlib/tests/test_globbing.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,6 @@
     )
 from bzrlib.tests import (
     TestCase,
-    TestCaseInTempDir,
     )
 
 

=== modified file 'bzrlib/tests/test_gpg.py'
--- bzrlib/tests/test_gpg.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_gpg.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Canonical Ltd
+# Copyright (C) 2005, 2006, 2007, 2009, 2011 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -18,12 +18,11 @@
 """Tests for signing and verifying blobs of data via gpg."""
 
 # import system imports here
-import os
 import sys
 
 from bzrlib import errors, ui
 import bzrlib.gpg as gpg
-from bzrlib.tests import TestCase, TestCaseInTempDir
+from bzrlib.tests import TestCase
 
 class FakeConfig(object):
 

=== modified file 'bzrlib/tests/test_graph.py'
--- bzrlib/tests/test_graph.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_graph.py	2011-01-12 01:01:53 +0000
@@ -17,7 +17,6 @@
 from bzrlib import (
     errors,
     graph as _mod_graph,
-    symbol_versioning,
     tests,
     )
 from bzrlib.revision import NULL_REVISION

=== modified file 'bzrlib/tests/test_hashcache.py'
--- bzrlib/tests/test_hashcache.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_hashcache.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 Canonical Ltd
+# Copyright (C) 2005-2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,13 +16,15 @@
 
 import os
 import stat
-import sys
 import time
 
 from bzrlib import osutils
 from bzrlib.errors import BzrError
 from bzrlib.hashcache import HashCache
-from bzrlib.tests import OsFifoFeature, TestCaseInTempDir, TestCase
+from bzrlib.tests import (
+    OsFifoFeature,
+    TestCaseInTempDir,
+    )
 
 
 def sha1(t):

=== modified file 'bzrlib/tests/test_help.py'
--- bzrlib/tests/test_help.py	2010-05-24 05:50:53 +0000
+++ bzrlib/tests/test_help.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2010 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,8 +16,6 @@
 
 """Unit tests for the bzrlib.help module."""
 
-from cStringIO import StringIO
-
 from bzrlib import (
     builtins,
     commands,

=== modified file 'bzrlib/tests/test_https_ca_bundle.py'
--- bzrlib/tests/test_https_ca_bundle.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_https_ca_bundle.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007, 2009, 2011 Canonical Ltd
+# Copyright (C) 2007, 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,8 +19,6 @@
 import os
 import sys
 
-import bzrlib
-from bzrlib import osutils
 from bzrlib.tests import (
     TestCaseInTempDir,
     TestSkipped,

=== modified file 'bzrlib/tests/test_ignores.py'
--- bzrlib/tests/test_ignores.py	2010-05-03 04:51:58 +0000
+++ bzrlib/tests/test_ignores.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,8 +18,15 @@
 
 from cStringIO import StringIO
 
-from bzrlib import config, errors, ignores
-from bzrlib.tests import TestCase, TestCaseInTempDir, TestCaseWithTransport
+from bzrlib import (
+    config,
+    ignores,
+    )
+from bzrlib.tests import (
+    TestCase,
+    TestCaseInTempDir,
+    TestCaseWithTransport,
+    )
 
 
 class TestParseIgnoreFile(TestCase):

=== modified file 'bzrlib/tests/test_info.py'
--- bzrlib/tests/test_info.py	2010-02-17 17:11:16 +0000
+++ bzrlib/tests/test_info.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2010 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,7 +15,6 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 import sys
-from urllib import quote
 
 from bzrlib import (
     branch as _mod_branch,

=== modified file 'bzrlib/tests/test_inv.py'
--- bzrlib/tests/test_inv.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_inv.py	2011-01-12 01:01:53 +0000
@@ -25,13 +25,18 @@
     revision,
     tests,
     )
-from bzrlib.inventory import (CHKInventory, Inventory, ROOT_ID, InventoryFile,
-    InventoryDirectory, InventoryEntry, TreeReference)
+from bzrlib.inventory import (
+    CHKInventory,
+    Inventory,
+    ROOT_ID,
+    InventoryFile,
+    InventoryDirectory,
+    InventoryEntry,
+    TreeReference,
+    )
 from bzrlib.tests import (
     TestCase,
     TestCaseWithTransport,
-    condition_isinstance,
-    multiply_tests,
     )
 from bzrlib.tests.per_workingtree import workingtree_formats
 from bzrlib.tests.scenarios import load_tests_apply_scenarios

=== modified file 'bzrlib/tests/test_inventory_delta.py'
--- bzrlib/tests/test_inventory_delta.py	2010-08-23 17:54:07 +0000
+++ bzrlib/tests/test_inventory_delta.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 Canonical Ltd
+# Copyright (C) 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@
 from cStringIO import StringIO
 
 from bzrlib import (
-    errors,
     inventory,
     inventory_delta,
     )

=== modified file 'bzrlib/tests/test_knit.py'
--- bzrlib/tests/test_knit.py	2010-06-20 11:18:38 +0000
+++ bzrlib/tests/test_knit.py	2011-01-11 17:54:38 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 """Tests for Knit data structure"""
 
 from cStringIO import StringIO
+import gzip
 import sys
 
 from bzrlib import (
@@ -27,7 +28,6 @@
     pack,
     tests,
     transport,
-    tuned_gzip,
     )
 from bzrlib.errors import (
     KnitHeaderError,
@@ -692,7 +692,7 @@
 
     def create_gz_content(self, text):
         sio = StringIO()
-        gz_file = tuned_gzip.GzipFile(mode='wb', fileobj=sio)
+        gz_file = gzip.GzipFile(mode='wb', fileobj=sio)
         gz_file.write(text)
         gz_file.close()
         return sio.getvalue()

=== modified file 'bzrlib/tests/test_lazy_import.py'
--- bzrlib/tests/test_lazy_import.py	2010-09-25 20:08:01 +0000
+++ bzrlib/tests/test_lazy_import.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,7 +24,10 @@
     lazy_import,
     osutils,
     )
-from bzrlib.tests import TestCase, TestCaseInTempDir
+from bzrlib.tests import (
+    TestCase,
+    TestCaseInTempDir,
+    )
 
 
 class InstrumentedReplacer(lazy_import.ScopeReplacer):

=== modified file 'bzrlib/tests/test_library_state.py'
--- bzrlib/tests/test_library_state.py	2010-06-26 01:07:16 +0000
+++ bzrlib/tests/test_library_state.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2010 Canonical Ltd
+# Copyright (C) 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
 
 """Tests for BzrLibraryState."""
 
-import bzrlib
 from bzrlib import (
     library_state,
     tests,

=== modified file 'bzrlib/tests/test_lockable_files.py'
--- bzrlib/tests/test_lockable_files.py	2010-06-20 11:18:38 +0000
+++ bzrlib/tests/test_lockable_files.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,8 +14,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from StringIO import StringIO
-
 import bzrlib
 from bzrlib import (
     errors,
@@ -23,11 +21,7 @@
     osutils,
     transport,
     )
-from bzrlib.errors import BzrBadParameterNotString, NoSuchFile, ReadOnlyError
 from bzrlib.lockable_files import LockableFiles, TransportLock
-from bzrlib.symbol_versioning import (
-    deprecated_in,
-    )
 from bzrlib.tests import (
     TestCaseInTempDir,
     TestNotApplicable,

=== modified file 'bzrlib/tests/test_lockdir.py'
--- bzrlib/tests/test_lockdir.py	2010-12-02 09:23:10 +0000
+++ bzrlib/tests/test_lockdir.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
 
 """Tests for LockDir"""
 
-from cStringIO import StringIO
 import os
 from threading import Thread, Lock
 import time
@@ -34,12 +33,14 @@
     LockBreakMismatch,
     LockBroken,
     LockContention,
-    LockError,
     LockFailed,
     LockNotHeld,
     )
 from bzrlib.lockdir import LockDir
-from bzrlib.tests import (features, TestCaseWithTransport)
+from bzrlib.tests import (
+    features,
+    TestCaseWithTransport,
+    )
 from bzrlib.trace import note
 
 # These tests sometimes use threads to test the behaviour of lock files with

=== modified file 'bzrlib/tests/test_lsprof.py'
--- bzrlib/tests/test_lsprof.py	2010-07-05 08:10:03 +0000
+++ bzrlib/tests/test_lsprof.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007, 2009, 2010 Canonical Ltd
+# Copyright (C) 2007, 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 
 
 import cPickle
-import os
 import threading
 
 import bzrlib

=== modified file 'bzrlib/tests/test_merge3.py'
--- bzrlib/tests/test_merge3.py	2010-04-26 16:59:56 +0000
+++ bzrlib/tests/test_merge3.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,11 +16,9 @@
 
 
 from bzrlib import (
-    errors,
     merge3,
     tests,
     )
-from bzrlib.merge3 import Merge3
 from bzrlib.errors import CantReprocessAndShowBase, BinaryFile
 
 def split_lines(t):

=== modified file 'bzrlib/tests/test_merge_core.py'
--- bzrlib/tests/test_merge_core.py	2010-02-23 07:43:11 +0000
+++ bzrlib/tests/test_merge_core.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,7 +24,11 @@
     merge_directive,
     osutils,
     )
-from bzrlib.conflicts import ContentsConflict, TextConflict, PathConflict
+from bzrlib.conflicts import (
+    ContentsConflict,
+    TextConflict,
+    PathConflict,
+    )
 from bzrlib.merge import (
     Merge3Merger,
     Diff3Merger,
@@ -32,7 +36,6 @@
     Merger,
     )
 from bzrlib.osutils import getcwd, pathjoin
-from bzrlib import progress
 from bzrlib.transform import TreeTransform
 from bzrlib.tests import TestCaseWithTransport, TestSkipped
 from bzrlib.workingtree import WorkingTree

=== modified file 'bzrlib/tests/test_missing.py'
--- bzrlib/tests/test_missing.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_missing.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Canonical Ltd
+# Copyright (C) 2005-2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,9 +14,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-import os
-
-
 from bzrlib import (
     missing,
     tests,
@@ -25,7 +22,6 @@
     iter_log_revisions,
     )
 from bzrlib.tests import TestCaseWithTransport
-from bzrlib.workingtree import WorkingTree
 
 
 class TestMissing(TestCaseWithTransport):

=== modified file 'bzrlib/tests/test_msgeditor.py'
--- bzrlib/tests/test_msgeditor.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_msgeditor.py	2011-01-12 01:01:53 +0000
@@ -29,8 +29,6 @@
     tests,
     trace,
     )
-from bzrlib.branch import Branch
-from bzrlib.config import ensure_config_dir_exists, config_filename
 from bzrlib.msgeditor import (
     make_commit_message_template_encoded,
     edit_commit_message_encoded

=== modified file 'bzrlib/tests/test_multiparent.py'
--- bzrlib/tests/test_multiparent.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_multiparent.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Canonical Ltd
+# Copyright (C) 2007, 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
 from unittest import TestCase
 
 from bzrlib import (
-    knit,
     multiparent,
     patiencediff,
     tests,

=== modified file 'bzrlib/tests/test_nonascii.py'
--- bzrlib/tests/test_nonascii.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_nonascii.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Canonical Ltd
+# Copyright (C) 2005, 2006, 2008, 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 from bzrlib import osutils
 from bzrlib.osutils import pathjoin
 from bzrlib.tests import TestCase, TestCaseWithTransport, TestSkipped
-from bzrlib.workingtree import WorkingTree
 
 
 class NonAsciiTest(TestCaseWithTransport):

=== modified file 'bzrlib/tests/test_options.py'
--- bzrlib/tests/test_options.py	2010-08-27 17:53:08 +0000
+++ bzrlib/tests/test_options.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
     option,
     )
 from bzrlib.builtins import cmd_commit
-from bzrlib.commands import Command, parse_args
+from bzrlib.commands import parse_args
 from bzrlib.tests import TestCase
 from bzrlib.repofmt import knitrepo
 

=== modified file 'bzrlib/tests/test_osutils_encodings.py'
--- bzrlib/tests/test_osutils_encodings.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_osutils_encodings.py	2011-01-12 01:01:53 +0000
@@ -18,11 +18,9 @@
 
 import codecs
 import locale
-import os
 import sys
 
 from bzrlib import (
-    errors,
     osutils,
     )
 from bzrlib.tests import (

=== modified file 'bzrlib/tests/test_permissions.py'
--- bzrlib/tests/test_permissions.py	2010-06-20 11:18:38 +0000
+++ bzrlib/tests/test_permissions.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify
@@ -32,8 +32,6 @@
 
 import os
 import sys
-import stat
-from cStringIO import StringIO
 import urllib
 
 from bzrlib import transport

=== modified file 'bzrlib/tests/test_progress.py'
--- bzrlib/tests/test_progress.py	2010-08-05 08:18:06 +0000
+++ bzrlib/tests/test_progress.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,16 +15,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
-import os
 from StringIO import StringIO
 
-from bzrlib import errors
 from bzrlib.progress import (
     ProgressTask,
     )
-from bzrlib.symbol_versioning import (
-    deprecated_in,
-    )
 from bzrlib.tests import TestCase
 from bzrlib.ui.text import (
     TextProgressView,

=== modified file 'bzrlib/tests/test_read_bundle.py'
--- bzrlib/tests/test_read_bundle.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_read_bundle.py	2011-01-12 01:01:53 +0000
@@ -17,18 +17,15 @@
 """Test read_bundle works properly across various transports."""
 
 import cStringIO
-import os
 
 import bzrlib.bundle
 from bzrlib.bundle.serializer import write_bundle
 import bzrlib.bzrdir
 import bzrlib.errors as errors
-from bzrlib.symbol_versioning import deprecated_in
 from bzrlib import tests
 from bzrlib.tests.test_transport import TestTransportImplementation
 from bzrlib.tests.per_transport import transport_test_permutations
 import bzrlib.transport
-from bzrlib.transport.memory import MemoryTransport
 import bzrlib.urlutils
 from bzrlib.tests.scenarios import load_tests_apply_scenarios
 

=== modified file 'bzrlib/tests/test_reconcile.py'
--- bzrlib/tests/test_reconcile.py	2010-06-20 11:18:38 +0000
+++ bzrlib/tests/test_reconcile.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2008, 2009, 2010 Canonical Ltd
+# Copyright (C) 2006, 2008-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,9 +23,7 @@
     tests,
     )
 from bzrlib.reconcile import reconcile, Reconciler
-from bzrlib.revision import Revision
 from bzrlib.tests import per_repository
-from bzrlib.workingtree import WorkingTree
 
 
 class TestWorksWithSharedRepositories(per_repository.TestCaseWithRepository):

=== modified file 'bzrlib/tests/test_registry.py'
--- bzrlib/tests/test_registry.py	2010-11-05 20:54:32 +0000
+++ bzrlib/tests/test_registry.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2008, 2009, 2010 Canonical Ltd
+# Copyright (C) 2006, 2008-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 
 from bzrlib import (
     branch,
-    errors,
     osutils,
     registry,
     tests,

=== modified file 'bzrlib/tests/test_remote.py'
--- bzrlib/tests/test_remote.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_remote.py	2011-01-12 01:01:53 +0000
@@ -61,8 +61,6 @@
 from bzrlib.smart.client import _SmartClient
 from bzrlib.smart.repository import SmartServerRepositoryGetParentMap
 from bzrlib.tests import (
-    condition_isinstance,
-    multiply_tests,
     test_server,
     )
 from bzrlib.tests.scenarios import load_tests_apply_scenarios
@@ -71,7 +69,7 @@
     RemoteTransport,
     RemoteSSHTransport,
     RemoteTCPTransport,
-)
+    )
 
 
 load_tests = load_tests_apply_scenarios

=== modified file 'bzrlib/tests/test_revision.py'
--- bzrlib/tests/test_revision.py	2010-07-15 12:37:32 +0000
+++ bzrlib/tests/test_revision.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,26 +15,19 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
-import os
 import warnings
 
 from bzrlib import (
     bugtracker,
     revision,
-    symbol_versioning,
     )
-from bzrlib.branch import Branch
 from bzrlib.errors import (
     InvalidBugStatus,
     InvalidLineInBugsProperty,
-    NoSuchRevision,
     )
-from bzrlib.deprecated_graph import Graph
-from bzrlib.revision import (find_present_ancestors,
-                             NULL_REVISION)
+from bzrlib.revision import NULL_REVISION
 from bzrlib.tests import TestCase, TestCaseWithTransport
 from bzrlib.trace import mutter
-from bzrlib.workingtree import WorkingTree
 
 # We're allowed to test deprecated interfaces
 warnings.filterwarnings('ignore',

=== modified file 'bzrlib/tests/test_revisionspec.py'
--- bzrlib/tests/test_revisionspec.py	2010-09-24 02:19:53 +0000
+++ bzrlib/tests/test_revisionspec.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,20 +15,15 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 import datetime
-import os
 import time
 
 from bzrlib import (
-    branch,
-    bzrdir,
     errors,
-    repository,
     revision as _mod_revision,
     )
-from bzrlib.tests import TestCase, TestCaseWithTransport
+from bzrlib.tests import TestCaseWithTransport
 from bzrlib.revisionspec import (
     RevisionSpec,
-    RevisionSpec_revno,
     RevisionSpec_tag,
     )
 

=== modified file 'bzrlib/tests/test_revisiontree.py'
--- bzrlib/tests/test_revisiontree.py	2010-02-17 17:11:16 +0000
+++ bzrlib/tests/test_revisiontree.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2008, 2009, 2010 Canonical Ltd
+# Copyright (C) 2006, 2008-2011 Canonical Ltd
 # Authors:  Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -21,8 +21,6 @@
     errors,
     revision,
     )
-import bzrlib
-from bzrlib.inventory import ROOT_ID
 from bzrlib.tests import TestCaseWithTransport
 
 

=== modified file 'bzrlib/tests/test_rio.py'
--- bzrlib/tests/test_rio.py	2010-09-25 20:08:01 +0000
+++ bzrlib/tests/test_rio.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2007, 2009, 2010 Canonical Ltd
+# Copyright (C) 2005, 2006, 2007, 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,18 +22,20 @@
 but this depends on the transport.
 """
 
-import cStringIO
-import os
 import re
-import sys
 from tempfile import TemporaryFile
 
 from bzrlib import (
     rio,
     )
-from bzrlib.tests import TestCaseInTempDir, TestCase
-from bzrlib.rio import (RioWriter, Stanza, read_stanza, read_stanzas, rio_file,
-                        RioReader)
+from bzrlib.tests import TestCase
+from bzrlib.rio import (
+    RioReader,
+    Stanza,
+    read_stanza,
+    read_stanzas,
+    rio_file,
+    )
 
 
 class TestRio(TestCase):

=== modified file 'bzrlib/tests/test_rules.py'
--- bzrlib/tests/test_rules.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_rules.py	2011-01-12 01:01:53 +0000
@@ -16,16 +16,13 @@
 
 """Tests for finding, parsing and searching rule-based preferences."""
 
-import os
 import sys
 
 from bzrlib import (
-    config,
     errors,
     rules,
     tests,
     )
-from bzrlib.util.configobj import configobj
 
 
 class TestIniBasedRulesSearcher(tests.TestCase):

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_selftest.py	2011-01-12 01:01:53 +0000
@@ -17,7 +17,7 @@
 """Tests for the test framework."""
 
 from cStringIO import StringIO
-from doctest import ELLIPSIS
+import doctest
 import os
 import signal
 import sys
@@ -42,7 +42,6 @@
 from bzrlib import (
     branchbuilder,
     bzrdir,
-    debug,
     errors,
     lockdir,
     memorytree,
@@ -56,7 +55,6 @@
     )
 from bzrlib.repofmt import (
     groupcompress_repo,
-    pack_repo,
     weaverepo,
     )
 from bzrlib.symbol_versioning import (
@@ -68,12 +66,10 @@
     features,
     test_lsprof,
     test_server,
-    test_sftp_transport,
     TestUtil,
     )
 from bzrlib.trace import note, mutter
 from bzrlib.transport import memory
-from bzrlib.version import _get_bzr_source_tree
 
 
 def _test_ids(test_suite):
@@ -92,7 +88,7 @@
             "text", "plain", {"charset": "utf8"})))
         self.assertThat(u"".join(log.iter_text()), Equals(self.get_log()))
         self.assertThat(self.get_log(),
-            DocTestMatches(u"...a test message\n", ELLIPSIS))
+            DocTestMatches(u"...a test message\n", doctest.ELLIPSIS))
 
 
 class TestUnicodeFilename(tests.TestCase):
@@ -3210,7 +3206,8 @@
         tpr.register('bar', 'bBB.aAA.rRR')
         self.assertEquals('bbb.aaa.rrr', tpr.get('bar'))
         self.assertThat(self.get_log(),
-            DocTestMatches("...bar...bbb.aaa.rrr...BB.aAA.rRR", ELLIPSIS))
+            DocTestMatches("...bar...bbb.aaa.rrr...BB.aAA.rRR",
+                           doctest.ELLIPSIS))
 
     def test_get_unknown_prefix(self):
         tpr = self._get_registry()
@@ -3412,28 +3409,6 @@
 
 class TestEnvironHandling(tests.TestCase):
 
-    def test__captureVar_None_called_twice_leaks(self):
-        self.failIf('MYVAR' in os.environ)
-        self._captureVar('MYVAR', '42')
-        # We need an embedded test to observe the bug
-        class Test(tests.TestCase):
-            def test_me(self):
-                # The first call save the 42 value
-                self._captureVar('MYVAR', None)
-                self.assertEquals(None, os.environ.get('MYVAR'))
-                self.assertEquals('42', self._old_env.get('MYVAR'))
-                # But the second one erases it !
-                self._captureVar('MYVAR', None)
-                self.assertEquals(None, self._old_env.get('MYVAR'))
-        output = StringIO()
-        result = tests.TextTestResult(output, 0, 1)
-        Test('test_me').run(result)
-        if not result.wasStrictlySuccessful():
-            self.fail(output.getvalue())
-        # And we have lost all trace of the original value
-        self.assertEquals(None, os.environ.get('MYVAR'))
-        self.assertEquals(None, self._old_env.get('MYVAR'))
-
     def test_overrideEnv_None_called_twice_doesnt_leak(self):
         self.failIf('MYVAR' in os.environ)
         self.overrideEnv('MYVAR', '42')
@@ -3453,3 +3428,121 @@
             self.fail(output.getvalue())
         # We get our value back
         self.assertEquals('42', os.environ.get('MYVAR'))
+
+
+class TestIsolatedEnv(tests.TestCase):
+    """Test isolating tests from os.environ.
+
+    Since we use tests that are already isolated from os.environ a bit of care
+    should be taken when designing the tests to avoid bootstrap side-effects.
+    The tests start an already clean os.environ which allow doing valid
+    assertions about which variables are present or not and design tests around
+    these assertions.
+    """
+
+    class ScratchMonkey(tests.TestCase):
+
+        def test_me(self):
+            pass
+
+    def test_basics(self):
+        # Make sure we know the definition of BZR_HOME: not part of os.environ
+        # for tests.TestCase.
+        self.assertTrue('BZR_HOME' in tests.isolated_environ)
+        self.assertEquals(None, tests.isolated_environ['BZR_HOME'])
+        # Being part of isolated_environ, BZR_HOME should not appear here
+        self.assertFalse('BZR_HOME' in os.environ)
+        # Make sure we know the definition of LINES: part of os.environ for
+        # tests.TestCase
+        self.assertTrue('LINES' in tests.isolated_environ)
+        self.assertEquals('25', tests.isolated_environ['LINES'])
+        self.assertEquals('25', os.environ['LINES'])
+
+    def test_injecting_unknown_variable(self):
+        # BZR_HOME is known to be absent from os.environ
+        test = self.ScratchMonkey('test_me')
+        tests.override_os_environ(test, {'BZR_HOME': 'foo'})
+        self.assertEquals('foo', os.environ['BZR_HOME'])
+        tests.restore_os_environ(test)
+        self.assertFalse('BZR_HOME' in os.environ)
+
+    def test_injecting_known_variable(self):
+        test = self.ScratchMonkey('test_me')
+        # LINES is known to be present in os.environ
+        tests.override_os_environ(test, {'LINES': '42'})
+        self.assertEquals('42', os.environ['LINES'])
+        tests.restore_os_environ(test)
+        self.assertEquals('25', os.environ['LINES'])
+
+    def test_deleting_variable(self):
+        test = self.ScratchMonkey('test_me')
+        # LINES is known to be present in os.environ
+        tests.override_os_environ(test, {'LINES': None})
+        self.assertTrue('LINES' not in os.environ)
+        tests.restore_os_environ(test)
+        self.assertEquals('25', os.environ['LINES'])
+
+
+class TestDocTestSuiteIsolation(tests.TestCase):
+    """Test that `tests.DocTestSuite` isolates doc tests from os.environ.
+
+    Since tests.TestCase alreay provides an isolation from os.environ, we use
+    the clean environment as a base for testing. To precisely capture the
+    isolation provided by tests.DocTestSuite, we use doctest.DocTestSuite to
+    compare against.
+
+    We want to make sure `tests.DocTestSuite` respect `tests.isolated_environ`,
+    not `os.environ` so each test overrides it to suit its needs.
+
+    """
+
+    def get_doctest_suite_for_string(self, klass, string):
+        class Finder(doctest.DocTestFinder):
+
+            def find(*args, **kwargs):
+                test = doctest.DocTestParser().get_doctest(
+                    string, {}, 'foo', 'foo.py', 0)
+                return [test]
+
+        suite = klass(test_finder=Finder())
+        return suite
+
+    def run_doctest_suite_for_string(self, klass, string):
+        suite = self.get_doctest_suite_for_string(klass, string)
+        output = StringIO()
+        result = tests.TextTestResult(output, 0, 1)
+        suite.run(result)
+        return result, output
+
+    def assertDocTestStringSucceds(self, klass, string):
+        result, output = self.run_doctest_suite_for_string(klass, string)
+        if not result.wasStrictlySuccessful():
+            self.fail(output.getvalue())
+
+    def assertDocTestStringFails(self, klass, string):
+        result, output = self.run_doctest_suite_for_string(klass, string)
+        if result.wasStrictlySuccessful():
+            self.fail(output.getvalue())
+
+    def test_injected_variable(self):
+        self.overrideAttr(tests, 'isolated_environ', {'LINES': '42'})
+        test = """
+            >>> import os
+            >>> os.environ['LINES']
+            '42'
+            """
+        # doctest.DocTestSuite fails as it sees '25'
+        self.assertDocTestStringFails(doctest.DocTestSuite, test)
+        # tests.DocTestSuite sees '42'
+        self.assertDocTestStringSucceds(tests.IsolatedDocTestSuite, test)
+
+    def test_deleted_variable(self):
+        self.overrideAttr(tests, 'isolated_environ', {'LINES': None})
+        test = """
+            >>> import os
+            >>> os.environ.get('LINES')
+            """
+        # doctest.DocTestSuite fails as it sees '25'
+        self.assertDocTestStringFails(doctest.DocTestSuite, test)
+        # tests.DocTestSuite sees None
+        self.assertDocTestStringSucceds(tests.IsolatedDocTestSuite, test)

=== modified file 'bzrlib/tests/test_server.py'
--- bzrlib/tests/test_server.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_server.py	2011-01-12 01:01:53 +0000
@@ -17,7 +17,6 @@
 import errno
 import socket
 import SocketServer
-import select
 import sys
 import threading
 

=== modified file 'bzrlib/tests/test_setup.py'
--- bzrlib/tests/test_setup.py	2010-11-05 14:07:45 +0000
+++ bzrlib/tests/test_setup.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2008, 2009, 2010 Canonical Ltd
+# Copyright (C) 2005, 2006, 2008-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,8 +19,6 @@
 import os
 import sys
 import subprocess
-import shutil
-from tempfile import TemporaryFile
 
 import bzrlib
 from bzrlib.tests import TestCase, TestSkipped

=== modified file 'bzrlib/tests/test_sftp_transport.py'
--- bzrlib/tests/test_sftp_transport.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_sftp_transport.py	2011-01-12 01:01:53 +0000
@@ -18,7 +18,6 @@
 import os
 import socket
 import sys
-import threading
 import time
 
 from bzrlib import (
@@ -30,7 +29,6 @@
     ui,
     )
 from bzrlib.osutils import (
-    pathjoin,
     lexists,
     )
 from bzrlib.tests import (
@@ -46,8 +44,6 @@
     from bzrlib.transport import sftp as _mod_sftp
     from bzrlib.tests import stub_sftp
 
-from bzrlib.workingtree import WorkingTree
-
 
 def set_test_transport_to_sftp(testcase):
     """A helper to set transports on test case instances."""

=== modified file 'bzrlib/tests/test_smart.py'
--- bzrlib/tests/test_smart.py	2010-05-13 16:17:54 +0000
+++ bzrlib/tests/test_smart.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,15 +25,11 @@
 """
 
 import bz2
-from cStringIO import StringIO
-import tarfile
 
 from bzrlib import (
-    bencode,
     branch as _mod_branch,
     bzrdir,
     errors,
-    pack,
     tests,
     transport,
     urlutils,
@@ -45,7 +41,6 @@
     repository as smart_repo,
     packrepository as smart_packrepo,
     request as smart_req,
-    server,
     vfs,
     )
 from bzrlib.tests import test_server

=== modified file 'bzrlib/tests/test_smtp_connection.py'
--- bzrlib/tests/test_smtp_connection.py	2010-08-30 07:34:11 +0000
+++ bzrlib/tests/test_smtp_connection.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007, 2009, 2010 Canonical Ltd
+# Copyright (C) 2007, 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from cStringIO import StringIO
 from email.Message import Message
 import errno
 import smtplib

=== modified file 'bzrlib/tests/test_store.py'
--- bzrlib/tests/test_store.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_store.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2007 Canonical Ltd
+# Copyright (C) 2005-2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,8 +21,7 @@
 import gzip
 
 import bzrlib.errors as errors
-from bzrlib.errors import BzrError, UnlistableStore, NoSuchFile
-from bzrlib.transport.local import LocalTransport
+from bzrlib.errors import BzrError
 from bzrlib.store.text import TextStore
 from bzrlib.tests import TestCase, TestCaseInTempDir, TestCaseWithTransport
 import bzrlib.store as store

=== modified file 'bzrlib/tests/test_strace.py'
--- bzrlib/tests/test_strace.py	2010-09-25 20:08:01 +0000
+++ bzrlib/tests/test_strace.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2010 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,8 +16,6 @@
 
 """Tests for the strace-invoking support."""
 
-import errno
-import subprocess
 import threading
 
 from bzrlib import (

=== modified file 'bzrlib/tests/test_subsume.py'
--- bzrlib/tests/test_subsume.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_subsume.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Canonical Ltd
+# Copyright (C) 2006-2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from bzrlib import bzrdir, errors, repository, workingtree, tests
+from bzrlib import errors, workingtree, tests
 
 
 class TestWorkingTree(tests.TestCaseWithTransport):

=== modified file 'bzrlib/tests/test_switch.py'
--- bzrlib/tests/test_switch.py	2010-05-03 04:08:50 +0000
+++ bzrlib/tests/test_switch.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2010 Canonical Ltd
+# Copyright (C) 2007-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
     merge as _mod_merge,
     switch,
     tests,
-)
+    )
 
 
 class TestSwitch(tests.TestCaseWithTransport):

=== modified file 'bzrlib/tests/test_symbol_versioning.py'
--- bzrlib/tests/test_symbol_versioning.py	2010-06-25 06:11:21 +0000
+++ bzrlib/tests/test_symbol_versioning.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@
 from bzrlib.symbol_versioning import (
     deprecated_function,
     deprecated_in,
-    deprecated_list,
     deprecated_method,
     )
 from bzrlib.tests import TestCase

=== modified file 'bzrlib/tests/test_transactions.py'
--- bzrlib/tests/test_transactions.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_transactions.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Canonical Ltd
+# Copyright (C) 2005, 2006, 2009, 2011 Canonical Ltd
 #   Authors: Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -17,13 +17,9 @@
 
 """Tests for the behaviour of the Transaction concept in bzr."""
 
-# import system imports here
-import os
-import sys
-
 #import bzrlib specific imports here
 import bzrlib.errors as errors
-from bzrlib.tests import TestCase, TestCaseInTempDir
+from bzrlib.tests import TestCase
 import bzrlib.transactions as transactions
 
 

=== modified file 'bzrlib/tests/test_transform.py'
--- bzrlib/tests/test_transform.py	2010-12-02 10:41:05 +0000
+++ bzrlib/tests/test_transform.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -52,7 +52,6 @@
     ImmortalPendingDeletion,
     LockError,
     MalformedTransform,
-    NoSuchFile,
     ReusingTransform,
 )
 from bzrlib.osutils import (
@@ -64,7 +63,6 @@
     features,
     HardlinkFeature,
     SymlinkFeature,
-    TestCase,
     TestCaseInTempDir,
     TestSkipped,
 )
@@ -74,7 +72,6 @@
     cook_conflicts,
     _FileMover,
     FinalPaths,
-    get_backup_name,
     resolve_conflicts,
     resolve_checkout,
     ROOT_PARENT,

=== modified file 'bzrlib/tests/test_transport.py'
--- bzrlib/tests/test_transport.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_transport.py	2011-01-12 01:01:53 +0000
@@ -16,7 +16,6 @@
 
 
 from cStringIO import StringIO
-import os
 import subprocess
 import sys
 import threading

=== modified file 'bzrlib/tests/test_transport_log.py'
--- bzrlib/tests/test_transport_log.py	2010-06-20 11:18:38 +0000
+++ bzrlib/tests/test_transport_log.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2008, 2009, 2010 Canonical Ltd
+# Copyright (C) 2008-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,8 +18,6 @@
 """Tests for log+ transport decorator."""
 
 
-import types
-
 from bzrlib import transport
 from bzrlib.tests import TestCaseWithMemoryTransport
 from bzrlib.trace import mutter

=== modified file 'bzrlib/tests/test_tree.py'
--- bzrlib/tests/test_tree.py	2009-08-28 05:00:33 +0000
+++ bzrlib/tests/test_tree.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2008 Canonical Ltd
+# Copyright (C) 2006-2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 from bzrlib import (
     errors,
     revision,
-    tests,
     tree as _mod_tree,
     )
 from bzrlib.tests import TestCaseWithTransport

=== modified file 'bzrlib/tests/test_tuned_gzip.py'
--- bzrlib/tests/test_tuned_gzip.py	2010-09-25 20:08:01 +0000
+++ bzrlib/tests/test_tuned_gzip.py	2011-01-11 18:10:55 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2009, 2010 Canonical Ltd
+# Copyright (C) 2006, 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,11 +21,14 @@
 # do not use bzrlib test cases here - this should be suitable for sending
 # upstream.
 from cStringIO import StringIO
-from unittest import TestCase
 import zlib
 
 
-from bzrlib import tuned_gzip
+from bzrlib import (
+    symbol_versioning,
+    tuned_gzip,
+    tests,
+    )
 
 
 class FakeDecompress(object):
@@ -42,7 +45,7 @@
         return ''
 
 
-class TestFakeDecompress(TestCase):
+class TestFakeDecompress(tests.TestCase):
     """We use a fake decompressor to test GzipFile.
 
     This class tests the behaviours we want from it.
@@ -67,14 +70,16 @@
         self.assertEqual('1234567', decompress.unused_data)
 
 
-class TestGzip(TestCase):
+class TestGzip(tests.TestCase):
 
     def test__read_short_remainder(self):
         # a _read call at the end of a compressed hunk should
         # read more bytes if there is less than 8 bytes (the
         # gzip trailer) unread.
         stream = StringIO('\0\0\0\0\0\0\0\0')
-        myfile = tuned_gzip.GzipFile(fileobj=stream)
+        myfile = self.applyDeprecated(
+            symbol_versioning.deprecated_in((2, 3, 0)),
+            tuned_gzip.GzipFile, fileobj=stream)
         # disable the _new_member check, we are microtesting.
         myfile._new_member = False
         myfile.crc = zlib.crc32('')
@@ -89,21 +94,25 @@
     def test_negative_crc(self):
         """Content with a negative crc should not break when written"""
         sio = StringIO()
-        gfile = tuned_gzip.GzipFile(mode="w", fileobj=sio)
+        gfile = self.applyDeprecated(
+            symbol_versioning.deprecated_in((2, 3, 0)),
+            tuned_gzip.GzipFile, mode="w", fileobj=sio)
         gfile.write("\xFF")
         gfile.close()
         self.assertEqual(gfile.crc & 0xFFFFFFFFL, 0xFF000000L)
         self.assertEqual(sio.getvalue()[-8:-4], "\x00\x00\x00\xFF")
 
 
-class TestToGzip(TestCase):
+class TestToGzip(tests.TestCase):
 
     def assertToGzip(self, chunks):
         bytes = ''.join(chunks)
         gzfromchunks = tuned_gzip.chunks_to_gzip(chunks)
         gzfrombytes = tuned_gzip.bytes_to_gzip(bytes)
         self.assertEqual(gzfrombytes, gzfromchunks)
-        decoded = tuned_gzip.GzipFile(fileobj=StringIO(gzfromchunks)).read()
+        decoded = self.applyDeprecated(
+            symbol_versioning.deprecated_in((2, 3, 0)),
+            tuned_gzip.GzipFile, fileobj=StringIO(gzfromchunks)).read()
         self.assertEqual(bytes, decoded)
 
     def test_single_chunk(self):

=== modified file 'bzrlib/tests/test_ui.py'
--- bzrlib/tests/test_ui.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_ui.py	2011-01-12 01:01:53 +0000
@@ -17,7 +17,6 @@
 """Tests for the bzrlib ui
 """
 
-import os
 import time
 
 from StringIO import StringIO
@@ -26,15 +25,10 @@
 
 from bzrlib import (
     config,
-    errors,
     remote,
-    repository,
     tests,
     ui as _mod_ui,
     )
-from bzrlib.symbol_versioning import (
-    deprecated_in,
-    )
 from bzrlib.tests import (
     fixtures,
     test_progress,

=== modified file 'bzrlib/tests/test_version.py'
--- bzrlib/tests/test_version.py	2010-02-17 17:11:16 +0000
+++ bzrlib/tests/test_version.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2009, 2010 Canonical Ltd
+# Copyright (C) 2006, 2009, 2010, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
 """Tests for versioning of bzrlib."""
 
 from cStringIO import StringIO
-import os
 import re
 
 from bzrlib import version, workingtree

=== modified file 'bzrlib/tests/test_version_info.py'
--- bzrlib/tests/test_version_info.py	2010-01-25 17:48:22 +0000
+++ bzrlib/tests/test_version_info.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@
 from bzrlib import (
     errors,
     registry,
-    symbol_versioning,
     tests,
     version_info_formats,
     )

=== modified file 'bzrlib/tests/test_weave.py'
--- bzrlib/tests/test_weave.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_weave.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Canonical Ltd
+# Copyright (C) 2005-2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
     )
 from bzrlib.osutils import sha_string
 from bzrlib.tests import TestCase, TestCaseInTempDir
-from bzrlib.weave import Weave, WeaveFormatError, WeaveError
+from bzrlib.weave import Weave, WeaveFormatError
 from bzrlib.weavefile import write_weave, read_weave
 
 

=== modified file 'bzrlib/tests/test_whitebox.py'
--- bzrlib/tests/test_whitebox.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_whitebox.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 Canonical Ltd
+# Copyright (C) 2005, 2006, 2008, 2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,13 +15,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 import os
-import unittest
 
 from bzrlib import (
     osutils,
     )
-from bzrlib.tests import TestCaseWithTransport, TestCase
-from bzrlib.branch import Branch
+from bzrlib.tests import TestCaseWithTransport
 from bzrlib.errors import PathNotChild
 from bzrlib.osutils import relpath, pathjoin, abspath, realpath
 

=== modified file 'bzrlib/tests/test_win32utils.py'
--- bzrlib/tests/test_win32utils.py	2011-01-10 22:20:12 +0000
+++ bzrlib/tests/test_win32utils.py	2011-01-12 01:01:53 +0000
@@ -17,7 +17,6 @@
 """Tests for win32utils."""
 
 import os
-import sys
 
 from bzrlib import (
     osutils,

=== modified file 'bzrlib/tests/test_workingtree.py'
--- bzrlib/tests/test_workingtree.py	2010-11-07 10:20:30 +0000
+++ bzrlib/tests/test_workingtree.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 # Authors:  Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -15,7 +15,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from cStringIO import StringIO
 import os
 
 from bzrlib import (
@@ -25,8 +24,6 @@
     transport,
     workingtree,
     )
-from bzrlib.branch import Branch
-from bzrlib.bzrdir import BzrDir
 from bzrlib.lockdir import LockDir
 from bzrlib.mutabletree import needs_tree_write_lock
 from bzrlib.tests import TestCase, TestCaseWithTransport, TestSkipped

=== modified file 'bzrlib/tests/test_wsgi.py'
--- bzrlib/tests/test_wsgi.py	2009-10-21 11:13:40 +0000
+++ bzrlib/tests/test_wsgi.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Canonical Ltd
+# Copyright (C) 2006-2009, 2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 from cStringIO import StringIO
 
 from bzrlib import tests
-from bzrlib.smart import medium, message, protocol
+from bzrlib.smart import medium, protocol
 from bzrlib.transport.http import wsgi
 from bzrlib.transport import chroot, memory
 

=== modified file 'bzrlib/tests/test_xml.py'
--- bzrlib/tests/test_xml.py	2010-02-17 17:11:16 +0000
+++ bzrlib/tests/test_xml.py	2011-01-12 01:01:53 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2010 Canonical Ltd
+# Copyright (C) 2005-2011 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,10 +23,9 @@
     xml6,
     xml7,
     xml8,
-    serializer,
     )
 from bzrlib.tests import TestCase
-from bzrlib.inventory import Inventory, InventoryEntry
+from bzrlib.inventory import Inventory
 from bzrlib.xml4 import serializer_v4
 import bzrlib.xml5
 

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2011-01-10 22:20:12 +0000
+++ bzrlib/transform.py	2011-01-12 01:01:53 +0000
@@ -19,10 +19,12 @@
 from stat import S_ISREG, S_IEXEC
 import time
 
+import bzrlib
 from bzrlib import (
     errors,
     lazy_import,
     registry,
+    tree,
     )
 lazy_import.lazy_import(globals(), """
 from bzrlib import (
@@ -50,20 +52,18 @@
     delete_any,
     file_kind,
     has_symlinks,
-    lexists,
     pathjoin,
     sha_file,
     splitpath,
     supports_executable,
-)
+    )
 from bzrlib.progress import ProgressPhase
 from bzrlib.symbol_versioning import (
-        deprecated_function,
-        deprecated_in,
-        deprecated_method,
-        )
-from bzrlib.trace import mutter, warning
-from bzrlib import tree
+    deprecated_function,
+    deprecated_in,
+    deprecated_method,
+    )
+from bzrlib.trace import warning
 import bzrlib.ui
 import bzrlib.urlutils as urlutils
 

=== modified file 'bzrlib/transport/ssh.py'
--- bzrlib/transport/ssh.py	2010-11-18 00:22:24 +0000
+++ bzrlib/transport/ssh.py	2011-01-11 20:20:13 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Robey Pointer <robey@lag.net>
+# Copyright (C) 2006-2011 Robey Pointer <robey@lag.net>
 # Copyright (C) 2005, 2006, 2007 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
@@ -359,6 +359,7 @@
         # whatever) chunks.
         try:
             my_sock, subproc_sock = socket.socketpair()
+            osutils.set_fd_cloexec(my_sock)
         except (AttributeError, socket.error):
             # This platform doesn't support socketpair(), so just use ordinary
             # pipes instead.

=== modified file 'bzrlib/tuned_gzip.py'
--- bzrlib/tuned_gzip.py	2010-09-25 20:08:01 +0000
+++ bzrlib/tuned_gzip.py	2011-01-11 18:10:55 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2010 Canonical Ltd
+# Copyright (C) 2006-2011 Canonical Ltd
 # Written by Robert Collins <robert.collins@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
 import zlib
 
 # we want a \n preserved, break on \n only splitlines.
-import bzrlib
+from bzrlib import symbol_versioning
 
 __all__ = ["GzipFile", "bytes_to_gzip"]
 
@@ -118,6 +118,13 @@
     Yes, its only 1.6 seconds, but they add up.
     """
 
+    def __init__(self, *args, **kwargs):
+        symbol_versioning.warn(
+            symbol_versioning.deprecated_in((2, 3, 0))
+            % 'bzrlib.tuned_gzip.GzipFile',
+            DeprecationWarning, stacklevel=2)
+        gzip.GzipFile.__init__(self, *args, **kwargs)
+
     def _add_read_data(self, data):
         # 4169 calls in 183
         # temp var for len(data) and switch to +='s.

=== modified file 'bzrlib/upgrade.py'
--- bzrlib/upgrade.py	2011-01-10 22:20:12 +0000
+++ bzrlib/upgrade.py	2011-01-12 01:01:53 +0000
@@ -19,12 +19,13 @@
 
 from bzrlib import (
     errors,
-    osutils,
-    repository,
     trace,
     ui,
     )
-from bzrlib.bzrdir import BzrDir, format_registry
+from bzrlib.bzrdir import (
+    BzrDir,
+    format_registry,
+    )
 from bzrlib.remote import RemoteBzrDir
 
 

=== modified file 'doc/developers/cycle.txt'
--- doc/developers/cycle.txt	2010-10-12 15:50:39 +0000
+++ doc/developers/cycle.txt	2011-01-03 23:48:17 +0000
@@ -274,10 +274,9 @@
 ---------
 
 At present we have three upstream-maintained PPAs containing Ubuntu packages
-of Bazaar: ``~bzr-nightly-ppa``, ``~bzr-beta-ppa`` (beta releases) and
-``~bzr`` (ie stable).  We will keep these PPAs, and reorient beta to contain
-the monthly beta releases, and the stable PPA to contain stable releases and
-bugfixes to those releases.
+of Bazaar: ``bzr/daily`` (snapshots), ``bzr-beta-ppa/ppa`` (beta releases) and
+``bzr/ppa`` (ie stable).  Beta contains the monthly beta releases, and the
+stable PPA contains stable releases and bugfixes to those releases.
 
 Some platforms with relatively less active packagers may choose to ship
 only the stable releases.  This is probably better than having them only

=== modified file 'doc/developers/ppa.txt'
--- doc/developers/ppa.txt	2010-10-12 15:50:39 +0000
+++ doc/developers/ppa.txt	2011-01-11 11:25:27 +0000
@@ -13,24 +13,32 @@
 
   __ https://help.launchpad.net/PPAQuickStart
 
-As of September 2010, there are four PPAs:
+As of January 2011, there are the following PPAs:
 
 <https://launchpad.net/~bzr/+archive/ppa>
     Final released versions and updates.
     Most users who want updates to bzr should add this.
 
 <https://launchpad.net/~bzr/+archive/proposed>
-    Proposed uploads to move into ~bzr, awaiting testing.
-
-<https://launchpad.net/~bzr-beta-ppa/+archive>
+    Proposed uploads to move into ~bzr/ppa, awaiting testing.
+
+<https://launchpad.net/~bzr/+archive/obsolete>
+    A preserved copy of the final version of packages from ~bzr/ppa for
+    obsolete Ubuntu series.
+
+<https://launchpad.net/~bzr-beta-ppa/+archive/ppa>
     Beta releases.
 
-<https://launchpad.net/~bzr-nightly-ppa/+archive>
+<https://launchpad.net/~bzr-beta-ppa/+archive/obsolete>
+    A preserved copy of the final version of packages from
+    ~bzr-beta-ppa/ppa for obsolete Ubuntu series.
+
+<https://launchpad.net/~bzr/+archive/daily>
     Automatic nightly builds from trunk.
 
-We build a distinct package for each distrorelease.  
+We build a distinct package for each distrorelease.
 If you upload a release-specific version, you should add a suffix to the
-package version, e.g. ``bzr.1.3-1~bazaar1~dapper1``.
+package version, e.g. ``1.3-1~bazaar1~dapper1``.
 
 Dapper uses the ``python-support`` framework and later distributions use
 ``python-central``.  This has little effect on everyday packaging but does
@@ -46,8 +54,8 @@
 <lp:~bzr/ubuntu/hardy/bzr/bzr-ppa>.  These branches are intended to be used
 with the ``bzr-builddeb`` plugin.
 
-**You should almost always upload to the beta ppa first** and then either 
-upload again or copy the packages into the release ppa.  That reduces the 
+**You should almost always upload to the proposed or beta ppa first** and
+then copy the packages into the release ppa.  That reduces the 
 risk of breaking the main archive from which people get bzr updates.
 
 
@@ -82,7 +90,7 @@
 On reasonably recent versions of Ubuntu you no longer need special dput
 configuration, because you can just say ::
 
-  dput ppa:bzr/proposed <source.changes
+  dput ppa:bzr/proposed source.changes
   
 
 However, you may still want to add these lines to ``~/.dput.cf`` prevent 
@@ -140,8 +148,8 @@
 use the script from <http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=255165> 
 to wrap it, and to give it sensible defaults for your local machine.
 
-Update all packages in proposed before copping the main ppa
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+Update all packages in proposed before copying to the main ppa
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 If one updates bzr, and there are plugins that are not compatible with the
 new version of bzr, this can cause pain for users using the ppa. In order to

=== modified file 'doc/developers/testing.txt'
--- doc/developers/testing.txt	2010-12-16 17:45:14 +0000
+++ doc/developers/testing.txt	2011-01-03 13:13:50 +0000
@@ -329,8 +329,11 @@
 We make selective use of doctests__.  In general they should provide
 *examples* within the API documentation which can incidentally be tested.  We
 don't try to test every important case using doctests |--| regular Python
-tests are generally a better solution.  That is, we just use doctests to
-make our documentation testable, rather than as a way to make tests.
+tests are generally a better solution.  That is, we just use doctests to make
+our documentation testable, rather than as a way to make tests. Be aware that
+doctests are not as well isolated as the unit tests, if you need more
+isolation, you're likely want to write unit tests anyway if only to get a
+better control of the test environment.
 
 Most of these are in ``bzrlib/doc/api``.  More additions are welcome.
 

=== modified file 'doc/en/release-notes/bzr-2.3.txt'
--- doc/en/release-notes/bzr-2.3.txt	2011-01-10 22:20:12 +0000
+++ doc/en/release-notes/bzr-2.3.txt	2011-01-12 01:01:53 +0000
@@ -35,11 +35,18 @@
   once.  This avoids some unnecessary IO, and removes a network roundtrip
   when doing ``bzr branch`` to a smart server URL.  (Andrew Bennetts)
 
+* ``bzr modified`` now read-locks the working tree (and branch and
+  repository) just once.  (Andrew Bennetts)
+  
 * ``bzr resolve`` now accepts ``--take-this`` and ``--take-other`` actions
   for text conflicts. This *replace* the whole file with the content
   designated by the action. This will *ignore* all differences that would
   have been merge cleanly otherwise. (Vincent Ladeuil, #638451)
 
+* ``bzr tags``'s "sort" argument now allows registering custom sort
+  methods using the ``bzrlib.tag.tag_sort_methods`` registry. 
+  (Jelmer Vernooij, #701244)
+
 * ``bt.test_http`` was breaking ``os.environ`` by erasing the values saved by
   ``TestCase`` leading to ``bt.test_import_tariff`` failures.
   (Vincent Ladeuil, #690563)
@@ -55,6 +62,18 @@
 .. Fixes for situations where bzr would previously crash or give incorrect
    or undesirable results.
 
+* Avoid leaking SSH subprocess communication socket into unrelated child
+  processes, which could cause bzr to hang on exit. (Max Bowsher, #696285)
+
+* ``bzr update`` in a checkout of a readonly branch works again, without
+  trying to set the tags in the master branch. This had been broken by the
+  bug fix for bug #603395.  (John Arbash Meinel, #701212)
+
+* Stop using ``bzrlib.tuned_gzip.GzipFile``. It is incompatible with
+  python-2.7 and was only used for Knit format repositories, which haven't
+  been recommended since 2007. The file itself will be removed in the next
+  release. (John Arbash Meinel)
+
 * You are now able to commit directly to a stacked branch. Any needed
   parent inventories will be filled in as part of the commit process.
   (John Arbash Meinel, #375013)
@@ -81,6 +100,10 @@
   already opened that repository).  Implementations of these APIs will
   need to be updated to accept these arguments.  (Andrew Bennetts)
 
+* ``bzrlib.tuned_gzip.GzipFile`` is now deprecated and will be removed in
+  the bzr-2.4 series. Code that was using it can just use the python
+  stdlib ``gzip.GzipFile``. (John Arbash Meinel)
+
 Internals
 *********
 
@@ -94,12 +117,26 @@
    suite.  This can include new facilities for writing tests, fixes to 
    spurious test failures and changes to the way things should be tested.
 
+* ``bzrlib.tests`` defines ``isolated_environ`` with the definitions of all
+  the environment variables the tests should care about. It also defines
+  ``override_os_environ`` and ``restore_os_environ`` to properly implement
+  isolation from ``os.environ`` for tests. ``bzrlib.tests`` now defines a
+  ``DocTestSuite`` class using this facility for all ``bzrlib``
+  doctests. (Vincent Ladeuil, #321320)
+
 * Catch exceptions related to bug #637821 during test cleanup to avoid
   spurious failures. (Vincent Ladeuil, #686008).
 
 * Check sphinx compatibility for tests requiring older sphinx versions.
   (Vincent Ladeuil, #688072)
 
+* ``test_onto_transport`` in the Launchpad plugin can now run with Python
+  2.7. (Vincent Ladeuil, #654733)
+
+* ``TestCase._captureVar`` and ``TestCase._old_env`` have been deleted due to
+  bug #690563. Test writers are encouraged to use ``TestCase.overrideEnv``
+  instead. (Vincent Ladeuil)
+
 * ``TestDebuntuExpansions`` was escaping the test isolation by calling the
   wrong base class ``setUp``. (Vincent Ladeuil, #684622)
 

=== modified file 'setup.py'
--- setup.py	2010-12-02 10:41:05 +0000
+++ setup.py	2010-12-26 13:19:11 +0000
@@ -395,7 +395,8 @@
     # ditto for the tbzrcommand tool
     tbzrcommand = dict(
         script = os.path.join(tbzr_root, "scripts", "tbzrcommand.py"),
-        icon_resources = [(0,'bzr.ico')],
+        icon_resources = icon_resources,
+        other_resources = other_resources,
     )
     console_targets.append(tbzrcommand)
     tbzrcommandw = tbzrcommand.copy()

=== modified file 'tools/packaging/build-packages.sh'
--- tools/packaging/build-packages.sh	2009-05-25 10:59:42 +0000
+++ tools/packaging/build-packages.sh	2011-01-11 11:26:48 +0000
@@ -1,5 +1,5 @@
 #!/bin/bash
-# A helper script to build packages for the various distributions
+# Helper to build packages for the various distributions
 
 if [ -z "$UBUNTU_RELEASES" ]; then
     echo "Configure the distro platforms that you want to"

=== modified file 'tools/packaging/update-changelogs.sh'
--- tools/packaging/update-changelogs.sh	2010-08-19 08:07:42 +0000
+++ tools/packaging/update-changelogs.sh	2011-01-11 11:26:48 +0000
@@ -1,4 +1,5 @@
 #!/bin/bash
+# Helper to insert a new entry in debian/changelog
 
 if [ -z "$UBUNTU_RELEASES" ]; then
     echo "Configure the distro platforms that you want to"

=== modified file 'tools/packaging/update-control.sh'
--- tools/packaging/update-control.sh	2009-09-02 04:08:08 +0000
+++ tools/packaging/update-control.sh	2011-01-11 11:26:48 +0000
@@ -1,4 +1,5 @@
 #!/bin/bash
+# Helper to run sed on versions in dependencies in debian/control
 
 if [ -z "$UBUNTU_RELEASES" ]; then
     echo "Configure the distro platforms that you want to"

